[SCM] Samba Shared Repository - branch v3-3-stable updated - release-3-3-0-138-g57930cf

2009-02-23 Thread Karolin Seeger
The branch, v3-3-stable has been updated
   via  57930cf3e4eb79b26cd062b51635d1df2d68a0ed (commit)
   via  f0e36527de04d2796097ebd29fba2a25fc2e1c38 (commit)
   via  733d4b54546d6c7c9350cf522d4980877edac6d4 (commit)
   via  1dd4404782ca2d12b3815e7e0fcb6e6045d690b0 (commit)
   via  18dce7a5cdf01ce4151ce2d0c26d9e1b80b50f72 (commit)
  from  e6f556d3820a828bf4a59aceda0e3546e74ef61f (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-stable


- Log -
commit 57930cf3e4eb79b26cd062b51635d1df2d68a0ed
Author: Karolin Seeger 
Date:   Tue Feb 24 08:37:27 2009 +0100

WHATSNEW: Update changes since 3.3.0.

Karolin
(cherry picked from commit 4f4a15f4c1f4f2f72f3f651b102938c48ac7ab5b)

commit f0e36527de04d2796097ebd29fba2a25fc2e1c38
Author: Jeremy Allison 
Date:   Mon Feb 23 16:23:42 2009 -0800

More warning fixes for Solaris.
Jeremy.
(cherry picked from commit aea38950ff4865f1d791cd19619fadcd59eaf480)

commit 733d4b54546d6c7c9350cf522d4980877edac6d4
Author: Jeremy Allison 
Date:   Mon Feb 23 15:42:52 2009 -0800

More warning fixes for Solaris.
Jeremy.
(cherry picked from commit 6306dd0cab617930176fdde91641344ef403429b)

commit 1dd4404782ca2d12b3815e7e0fcb6e6045d690b0
Author: Jeremy Allison 
Date:   Mon Feb 23 15:02:52 2009 -0800

Quieten down a boatload of shadowed variable warnings on Solaris.
Makes real problems easier to spot.
Jeremy.
(cherry picked from commit d32b6d5afd6437544c0fc42681351552d89907dc)

commit 18dce7a5cdf01ce4151ce2d0c26d9e1b80b50f72
Author: Björn Jacke 
Date:   Sun Feb 22 00:43:38 2009 +0100

all BSDs use this evironment variable

Signed-off-by: Stefan Metzmacher 
(cherry picked from commit cd6ae0de52164dd6f50b3614f2511acb3eb15993)
(cherry picked from commit 1ad5f50bdab761c7d3894e94f8fe3b171ec1b219)

---

Summary of changes:
 WHATSNEW.txt|2 +
 source/client/client.c  |6 +-
 source/include/proto.h  |4 +-
 source/lib/ldap_debug_handler.c |4 +-
 source/lib/replace/getifaddrs.c |9 
 source/lib/replace/libreplace_ld.m4 |2 +-
 source/lib/smbldap.c|2 +
 source/lib/system.c |3 +-
 source/lib/util_file.c  |4 +-
 source/lib/util_tdb.c   |6 ++-
 source/libgpo/gpo_reg.c |8 ++--
 source/librpc/ndr/ndr_sec_helper.c  |8 ++--
 source/libsmb/libsmb_dir.c  |2 +-
 source/modules/nfs4_acls.c  |   84 +-
 source/modules/nfs4_acls.h  |   10 ++--
 source/modules/vfs_extd_audit.c |8 ++--
 source/modules/vfs_solarisacl.c |9 ++--
 source/nmbd/nmbd.c  |   14 +++---
 source/registry/reg_dispatcher.c|8 ++--
 source/rpc_server/srv_svcctl_nt.c   |6 +-
 source/services/services_db.c   |6 +-
 source/smbd/connection.c|2 +-
 source/smbd/open.c  |2 +-
 source/smbd/posix_acls.c|   52 +++---
 source/smbd/server.c|2 +-
 source/smbd/sesssetup.c |4 +-
 source/utils/profiles.c |   30 ++--
 source/utils/sharesec.c |6 +-
 source/utils/smbget.c   |6 ++-
 source/winbindd/winbindd.c  |2 +-
 source/winbindd/winbindd_cache.c|   18 
 source/winbindd/winbindd_dual.c |2 +-
 32 files changed, 164 insertions(+), 167 deletions(-)


Changeset truncated at 500 lines:

diff --git a/WHATSNEW.txt b/WHATSNEW.txt
index 9377d89..141d76b 100644
--- a/WHATSNEW.txt
+++ b/WHATSNEW.txt
@@ -47,6 +47,7 @@ o   Jeremy Allison 
 * Backport the semantics of when to delete alternate data streams on a file
   truncate.
 * Fix printf warnings.
+* Fix warnings on Solaris.
 
 
 o   Michael Adam 
@@ -78,6 +79,7 @@ o   Bjoern Jacke 
 * Add configure check for Tru64 sub-second timestamp resolution.
 * Add Tru64 sub-second resolution timestamp support.
 * Enable IPv6 support for NetBSD and FreeBSD.
+* Use correct BSD evironment variable.
 
 
 o   Guenter Kukkukk 
diff --git a/source/client/client.c b/source/client/client.c
index df92bae..53bd9e6 100644
--- a/source/client/client.c
+++ b/source/client/client.c
@@ -1785,13 +1785,13 @@ static struct file_list {
  Free a file_list structure.
 /
 
-static void free_file_list (struct file_list *list_head)
+static void free_file_list (struct file_list *l_head)
 {
struct file_list *list, *next;
 
-   for (list = list_head; list; list = next) {
+   for (list = l_head; list; list = next) {
next = list->next;
-   DLIST_REMOVE(list_head, list);
+   DLIST_REMOVE(l_head, list);

[SCM] Samba Shared Repository - branch v3-3-test updated - release-3-2-0pre2-5008-g4f4a15f

2009-02-23 Thread Karolin Seeger
The branch, v3-3-test has been updated
   via  4f4a15f4c1f4f2f72f3f651b102938c48ac7ab5b (commit)
  from  aea38950ff4865f1d791cd19619fadcd59eaf480 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-test


- Log -
commit 4f4a15f4c1f4f2f72f3f651b102938c48ac7ab5b
Author: Karolin Seeger 
Date:   Tue Feb 24 08:37:27 2009 +0100

WHATSNEW: Update changes since 3.3.0.

Karolin

---

Summary of changes:
 WHATSNEW.txt |2 ++
 1 files changed, 2 insertions(+), 0 deletions(-)


Changeset truncated at 500 lines:

diff --git a/WHATSNEW.txt b/WHATSNEW.txt
index 9377d89..141d76b 100644
--- a/WHATSNEW.txt
+++ b/WHATSNEW.txt
@@ -47,6 +47,7 @@ o   Jeremy Allison 
 * Backport the semantics of when to delete alternate data streams on a file
   truncate.
 * Fix printf warnings.
+* Fix warnings on Solaris.
 
 
 o   Michael Adam 
@@ -78,6 +79,7 @@ o   Bjoern Jacke 
 * Add configure check for Tru64 sub-second timestamp resolution.
 * Add Tru64 sub-second resolution timestamp support.
 * Enable IPv6 support for NetBSD and FreeBSD.
+* Use correct BSD evironment variable.
 
 
 o   Guenter Kukkukk 


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1113-g997dfbb

2009-02-23 Thread Tim Prouty
The branch, master has been updated
   via  997dfbbf5409a9df3b3c87025fa80fb6bdafcac2 (commit)
   via  7bcaaf14fbf22805d88b945256b6bd31121c7c66 (commit)
  from  8d63c596a0f512c96f5663c0a9bd49d3c98c6df9 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 997dfbbf5409a9df3b3c87025fa80fb6bdafcac2
Author: Tim Prouty 
Date:   Mon Feb 23 17:43:47 2009 -0800

s3 OneFS: Fix a double free in an error path

commit 7bcaaf14fbf22805d88b945256b6bd31121c7c66
Author: Tim Prouty 
Date:   Sun Feb 22 20:50:30 2009 -0800

s3 OneFS: Add a parameter that unconditionally allows execute access

---

Summary of changes:
 source3/modules/onefs.h|2 ++
 source3/modules/onefs_system.c |   24 
 source3/smbd/oplock_onefs.c|5 ++---
 3 files changed, 28 insertions(+), 3 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/modules/onefs.h b/source3/modules/onefs.h
index a70664b..418e13d 100644
--- a/source3/modules/onefs.h
+++ b/source3/modules/onefs.h
@@ -41,6 +41,8 @@ enum onefs_acl_wire_format
 #define PARM_ONEFS_TYPE "onefs"
 #define PARM_ACL_WIRE_FORMAT "acl wire format"
 #define PARM_ACL_WIRE_FORMAT_DEFAULT ACL_FORMAT_WINDOWS_SD
+#define PARM_ALLOW_EXECUTE_ALWAYS "allow execute always"
+#define PARM_ALLOW_EXECUTE_ALWAYS_DEFAULT false
 #define PARM_ATIME_NOW "atime now files"
 #define PARM_ATIME_NOW_DEFAULT  NULL
 #define PARM_ATIME_STATIC  "atime static files"
diff --git a/source3/modules/onefs_system.c b/source3/modules/onefs_system.c
index 1080289..76df006 100644
--- a/source3/modules/onefs_system.c
+++ b/source3/modules/onefs_system.c
@@ -132,6 +132,30 @@ int onefs_sys_create_file(connection_struct *conn,
if (lp_nt_acl_support(SNUM(conn)) && !lp_inherit_perms(SNUM(conn)))
cf_flags = cf_flags_or(cf_flags, CF_FLAGS_DEFAULT_ACL);
 
+   /*
+* Some customer workflows require the execute bit to be ignored.
+*/
+   if (lp_parm_bool(SNUM(conn), PARM_ONEFS_TYPE,
+PARM_ALLOW_EXECUTE_ALWAYS,
+PARM_ALLOW_EXECUTE_ALWAYS_DEFAULT) &&
+   (open_access_mask & FILE_EXECUTE)) {
+
+   DEBUG(3, ("Stripping execute bit from %s: (0x%x)\n", path,
+ open_access_mask));
+
+   /* Strip execute. */
+   open_access_mask &= ~FILE_EXECUTE;
+
+   /*
+* Add READ_DATA, so we're not left with desired_access=0. An
+* execute call should imply the client will read the data.
+*/
+   open_access_mask |= FILE_READ_DATA;
+
+   DEBUGADD(3, ("New stripped access mask: 0x%x\n",
+open_access_mask));
+   }
+
DEBUG(10,("onefs_sys_create_file: base_fd = %d, "
  "open_access_mask = 0x%x, flags = 0x%x, mode = 0%o, "
  "desired_oplock = %s, id = 0x%x, secinfo = 0x%x, sd = %p, "
diff --git a/source3/smbd/oplock_onefs.c b/source3/smbd/oplock_onefs.c
index 0908ce4..d4f181f 100644
--- a/source3/smbd/oplock_onefs.c
+++ b/source3/smbd/oplock_onefs.c
@@ -744,13 +744,13 @@ struct kernel_oplocks 
*onefs_init_kernel_oplocks(TALLOC_CTX *mem_ctx)
po.po_flags_on |= P_NON_BLOCKING_SEMLOCK;
if (setprocoptions(&po) != 0) {
DEBUG(0, ("setprocoptions failed: %s.\n", strerror(errno)));
-   goto err_out;
+   return NULL;
}
 
/* Setup the oplock contexts */
_ctx = talloc_zero(mem_ctx, struct kernel_oplocks);
if (!_ctx) {
-   goto err_out;
+   return NULL;
}
 
ctx = talloc_zero(_ctx, struct onefs_oplocks_context);
@@ -788,7 +788,6 @@ struct kernel_oplocks *onefs_init_kernel_oplocks(TALLOC_CTX 
*mem_ctx)
 
  err_out:
talloc_free(_ctx);
-   talloc_free(ctx);
return NULL;
 }
 


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1111-g8d63c59

2009-02-23 Thread Steven Danneman
The branch, master has been updated
   via  8d63c596a0f512c96f5663c0a9bd49d3c98c6df9 (commit)
  from  3a1b4c00eb96634229fb730e9b38e8df5180756a (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 8d63c596a0f512c96f5663c0a9bd49d3c98c6df9
Author: Steven Danneman 
Date:   Mon Feb 23 20:46:11 2009 -0800

Refactored sys_fork() and sys_pid() into shared util library

This fixes a bug in 116ce19b, where we didn't clear the pid cache in
become_daemon() and thus the /var/run/smbd.pid didn't match the actual
pid of the parent process.

Currently S4 will clear the pid cache on fork but doesn't yet take
advantage of the pid cache by using sys_pid() instead of the direct
get_pid().

---

Summary of changes:
 lib/util/become_daemon.c |6 +++---
 lib/util/system.c|   29 +
 lib/util/util.h  |   10 ++
 source3/Makefile.in  |2 +-
 source3/include/proto.h  |2 --
 source3/lib/system.c |   29 -
 6 files changed, 43 insertions(+), 35 deletions(-)


Changeset truncated at 500 lines:

diff --git a/lib/util/become_daemon.c b/lib/util/become_daemon.c
index 5a97b65..3d06a43 100644
--- a/lib/util/become_daemon.c
+++ b/lib/util/become_daemon.c
@@ -66,10 +66,10 @@ _PUBLIC_ void close_low_fds(bool stderr_too)
  Become a daemon, discarding the controlling terminal.
 /
 
-_PUBLIC_ void become_daemon(bool Fork, bool no_process_group)
+_PUBLIC_ void become_daemon(bool do_fork, bool no_process_group)
 {
-   if (Fork) {
-   if (fork()) {
+   if (do_fork) {
+   if (sys_fork()) {
_exit(0);
}
}
diff --git a/lib/util/system.c b/lib/util/system.c
index 9bd1800..9bf5de1 100644
--- a/lib/util/system.c
+++ b/lib/util/system.c
@@ -88,3 +88,32 @@ _PUBLIC_ struct in_addr sys_inet_makeaddr(int net, int host)
return in2;
 }
 
+/**
+ Wrapper for fork. Ensures we clear our pid cache.
+/
+
+static pid_t mypid = (pid_t)-1;
+
+_PUBLIC_ pid_t sys_fork(void)
+{
+   pid_t forkret = fork();
+
+   if (forkret == (pid_t)0) {
+   /* Child - reset mypid so sys_getpid does a system call. */
+   mypid = (pid_t) -1;
+   }
+
+   return forkret;
+}
+
+/**
+ Wrapper for getpid. Ensures we only do a system call *once*.
+/
+
+_PUBLIC_ pid_t sys_getpid(void)
+{
+   if (mypid == (pid_t)-1)
+   mypid = getpid();
+
+   return mypid;
+}
diff --git a/lib/util/util.h b/lib/util/util.h
index d3e446f..27f94cd 100644
--- a/lib/util/util.h
+++ b/lib/util/util.h
@@ -134,6 +134,16 @@ apparent reason.
 _PUBLIC_ struct hostent *sys_gethostbyname(const char *name);
 _PUBLIC_ struct in_addr sys_inet_makeaddr(int net, int host);
 
+/**
+ * Wrapper for fork used to invalid pid cache.
+ **/
+_PUBLIC_ pid_t sys_fork(void);
+
+/**
+ * Wrapper for getpid. Ensures we only do a system call *once*.
+ **/
+_PUBLIC_ pid_t sys_getpid(void);
+
 /* The following definitions come from lib/util/genrand.c  */
 
 /**
diff --git a/source3/Makefile.in b/source3/Makefile.in
index 7564659..a403f14 100644
--- a/source3/Makefile.in
+++ b/source3/Makefile.in
@@ -339,7 +339,7 @@ UTIL_OBJ = ../lib/util/rbtree.o ../lib/util/signal.o 
../lib/util/time.o \
   ../lib/util/util.o ../lib/util/fsusage.o \
   ../lib/util/params.o ../lib/util/talloc_stack.o \
   ../lib/util/genrand.o ../lib/util/util_net.o \
-  ../lib/util/become_daemon.o
+  ../lib/util/become_daemon.o ../lib/util/system.o
 
 CRYPTO_OBJ = ../lib/crypto/crc32.o ../lib/crypto/md5.o \
 ../lib/crypto/hmacmd5.o ../lib/crypto/arcfour.o \
diff --git a/source3/include/proto.h b/source3/include/proto.h
index faf47d3..14241d5 100644
--- a/source3/include/proto.h
+++ b/source3/include/proto.h
@@ -972,8 +972,6 @@ struct passwd *sys_getpwnam(const char *name);
 struct passwd *sys_getpwuid(uid_t uid);
 struct group *sys_getgrnam(const char *name);
 struct group *sys_getgrgid(gid_t gid);
-pid_t sys_fork(void);
-pid_t sys_getpid(void);
 int sys_popen(const char *command);
 int sys_pclose(int fd);
 ssize_t sys_getxattr (const char *path, const char *name, void *value, size_t 
size);
diff --git a/source3/lib/system.c b/source3/lib/system.c
index 8bdc9fa..10b55f6 100644
--- a/source3/lib/system.c
+++ b/source3/lib/system.c
@@ -1043,35 +1043,6 @@ static char **extract_

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1110-g3a1b4c0

2009-02-23 Thread Andrew Tridgell
The branch, master has been updated
   via  3a1b4c00eb96634229fb730e9b38e8df5180756a (commit)
   via  b9860043dc092df25d4a39074e106d7367ebbe8f (commit)
   via  0016b9cee8d9e640e0b4604a81a900708a944c0d (commit)
  from  faa1100d229aef56da5d48f5c19ec901e520f8ef (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 3a1b4c00eb96634229fb730e9b38e8df5180756a
Merge: b9860043dc092df25d4a39074e106d7367ebbe8f 
faa1100d229aef56da5d48f5c19ec901e520f8ef
Author: Andrew Tridgell 
Date:   Tue Feb 24 11:40:28 2009 +1100

Merge branch 'master' of ssh://git.samba.org/data/git/samba

commit b9860043dc092df25d4a39074e106d7367ebbe8f
Author: Andrew Tridgell 
Date:   Tue Feb 24 11:39:44 2009 +1100

fixed the event context for net vampire

commit 0016b9cee8d9e640e0b4604a81a900708a944c0d
Author: Andrew Tridgell 
Date:   Tue Feb 24 10:48:11 2009 +1100

added a missing linefeed

---

Summary of changes:
 source4/utils/net/net.c  |2 +-
 source4/utils/net/net_join.c |2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/utils/net/net.c b/source4/utils/net/net.c
index ba5296f..d934403 100644
--- a/source4/utils/net/net.c
+++ b/source4/utils/net/net.c
@@ -107,7 +107,7 @@ static const struct net_functable net_functable[] = {
{"vampire", "join and syncronise an AD domain onto the local server\n", 
net_vampire, net_vampire_usage},
{"samsync", "synchronise into the local ldb the sam of an NT4 
domain\n", net_samsync_ldb, net_samsync_ldb_usage},
{"user", "manage user accounts\n", net_user, net_user_usage},
-   {"machinepw", "Get a machine password out of our SAM", net_machinepw,
+   {"machinepw", "Get a machine password out of our SAM\n", net_machinepw,
 net_machinepw_usage},
{NULL, NULL, NULL, NULL}
 };
diff --git a/source4/utils/net/net_join.c b/source4/utils/net/net_join.c
index ad63340..b0a25bb 100644
--- a/source4/utils/net/net_join.c
+++ b/source4/utils/net/net_join.c
@@ -126,7 +126,7 @@ int net_vampire(struct net_context *ctx, int argc, const 
char **argv)
 
domain_name = tmp;
 
-   libnetctx = libnet_context_init(NULL, ctx->lp_ctx);
+   libnetctx = libnet_context_init(ctx->event_ctx, ctx->lp_ctx);
if (!libnetctx) {
return -1;  
}


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-3-test updated - release-3-2-0pre2-5007-gaea3895

2009-02-23 Thread Jeremy Allison
The branch, v3-3-test has been updated
   via  aea38950ff4865f1d791cd19619fadcd59eaf480 (commit)
  from  6306dd0cab617930176fdde91641344ef403429b (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-test


- Log -
commit aea38950ff4865f1d791cd19619fadcd59eaf480
Author: Jeremy Allison 
Date:   Mon Feb 23 16:23:42 2009 -0800

More warning fixes for Solaris.
Jeremy.

---

Summary of changes:
 source/client/client.c   |6 ++--
 source/include/proto.h   |2 +-
 source/lib/ldap_debug_handler.c  |4 +--
 source/lib/replace/getifaddrs.c  |9 --
 source/lib/smbldap.c |2 +
 source/lib/system.c  |3 +-
 source/lib/util_file.c   |4 +-
 source/lib/util_tdb.c|6 +++-
 source/libsmb/libsmb_dir.c   |2 +-
 source/modules/vfs_extd_audit.c  |8 +++---
 source/nmbd/nmbd.c   |   14 +-
 source/smbd/connection.c |2 +-
 source/smbd/open.c   |2 +-
 source/smbd/posix_acls.c |   52 +++---
 source/smbd/server.c |2 +-
 source/smbd/sesssetup.c  |4 +-
 source/utils/smbget.c|6 +++-
 source/winbindd/winbindd.c   |2 +-
 source/winbindd/winbindd_cache.c |   18 ++--
 source/winbindd/winbindd_dual.c  |2 +-
 20 files changed, 72 insertions(+), 78 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source/client/client.c b/source/client/client.c
index df92bae..53bd9e6 100644
--- a/source/client/client.c
+++ b/source/client/client.c
@@ -1785,13 +1785,13 @@ static struct file_list {
  Free a file_list structure.
 /
 
-static void free_file_list (struct file_list *list_head)
+static void free_file_list (struct file_list *l_head)
 {
struct file_list *list, *next;
 
-   for (list = list_head; list; list = next) {
+   for (list = l_head; list; list = next) {
next = list->next;
-   DLIST_REMOVE(list_head, list);
+   DLIST_REMOVE(l_head, list);
SAFE_FREE(list->file_path);
SAFE_FREE(list);
}
diff --git a/source/include/proto.h b/source/include/proto.h
index 981a0ee..72d3ffe 100644
--- a/source/include/proto.h
+++ b/source/include/proto.h
@@ -1374,7 +1374,7 @@ bool unmap_file(void* start, size_t size);
 void *map_file(char *fname, size_t size);
 char **file_lines_load(const char *fname, int *numlines, size_t maxsize);
 char **fd_lines_load(int fd, int *numlines, size_t maxsize);
-char **file_lines_pload(char *syscmd, int *numlines);
+char **file_lines_pload(const char *syscmd, int *numlines);
 void file_lines_free(char **lines);
 void file_lines_slashcont(char **lines);
 bool file_save(const char *fname, void *packet, size_t length);
diff --git a/source/lib/ldap_debug_handler.c b/source/lib/ldap_debug_handler.c
index 2181ff0..98623d1 100644
--- a/source/lib/ldap_debug_handler.c
+++ b/source/lib/ldap_debug_handler.c
@@ -19,13 +19,11 @@
 
 #include "includes.h"
 
-#if HAVE_LDAP
-
+#if defined(HAVE_LDAP) && defined(HAVE_LBER_LOG_PRINT_FN)
 static void samba_ldap_log_print_fn(LDAP_CONST char *data)
 {
DEBUG(lp_ldap_debug_threshold(), ("[LDAP] %s", data));
 }
-
 #endif
 
 void init_ldap_debugging(void)
diff --git a/source/lib/replace/getifaddrs.c b/source/lib/replace/getifaddrs.c
index f6f0ec0..3a91bb4 100644
--- a/source/lib/replace/getifaddrs.c
+++ b/source/lib/replace/getifaddrs.c
@@ -84,9 +84,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
char buff[8192];
int fd, i, n;
struct ifreq *ifr=NULL;
-   struct in_addr ipaddr;
-   struct in_addr nmask;
-   char *iname;
struct ifaddrs *curif;
struct ifaddrs *lastif = NULL;
 
@@ -164,9 +161,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
char buff[8192];
int fd, i, n;
struct ifreq *ifr=NULL;
-   struct in_addr ipaddr;
-   struct in_addr nmask;
-   char *iname;
struct ifaddrs *curif;
struct ifaddrs *lastif = NULL;
 
@@ -265,9 +259,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
int fd, i;
struct ifconf ifc;
struct ifreq *ifr=NULL;
-   struct in_addr ipaddr;
-   struct in_addr nmask;
-   char *iname;
struct ifaddrs *curif;
struct ifaddrs *lastif = NULL;
 
diff --git a/source/lib/smbldap.c b/source/lib/smbldap.c
index 8e7ecdf..7e9f1ac 100644
--- a/source/lib/smbldap.c
+++ b/source/lib/smbldap.c
@@ -581,7 +581,9 @@ static void smbldap_store_state(LDAP *ld, struct 
smbldap_state *smbldap_state)
 
 int smb_ldap_start_tls(LDAP *ldap_struct, int version)
 { 
+#ifdef LDAP_OPT_X_TLS
int rc;
+#endif

if (lp_ldap_ssl() != LDAP_SSL_START_TLS) {

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1107-gfaa1100

2009-02-23 Thread Jeremy Allison
The branch, master has been updated
   via  faa1100d229aef56da5d48f5c19ec901e520f8ef (commit)
  from  bcd6e5ec3315b14cedf7437a70c34d233ded082e (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit faa1100d229aef56da5d48f5c19ec901e520f8ef
Author: Jeremy Allison 
Date:   Mon Feb 23 16:22:43 2009 -0800

More warning fixes for Solaris.
Jeremy.

---

Summary of changes:
 lib/replace/getifaddrs.c  |9 --
 source3/client/client.c   |6 ++--
 source3/lib/ldap_debug_handler.c  |4 +--
 source3/lib/smbldap.c |2 +
 source3/lib/system.c  |3 +-
 source3/lib/tdb_validate.c|5 ++-
 source3/libsmb/libsmb_dir.c   |2 +-
 source3/modules/vfs_extd_audit.c  |8 +++---
 source3/nmbd/nmbd.c   |   14 +-
 source3/smbd/open.c   |2 +-
 source3/smbd/posix_acls.c |   52 ++--
 source3/smbd/server.c |2 +-
 source3/smbd/sesssetup.c  |4 +-
 source3/utils/smbget.c|6 +++-
 source3/winbindd/winbindd.c   |2 +-
 source3/winbindd/winbindd_cache.c |   18 ++--
 source3/winbindd/winbindd_dual.c  |2 +-
 17 files changed, 67 insertions(+), 74 deletions(-)


Changeset truncated at 500 lines:

diff --git a/lib/replace/getifaddrs.c b/lib/replace/getifaddrs.c
index f6f0ec0..3a91bb4 100644
--- a/lib/replace/getifaddrs.c
+++ b/lib/replace/getifaddrs.c
@@ -84,9 +84,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
char buff[8192];
int fd, i, n;
struct ifreq *ifr=NULL;
-   struct in_addr ipaddr;
-   struct in_addr nmask;
-   char *iname;
struct ifaddrs *curif;
struct ifaddrs *lastif = NULL;
 
@@ -164,9 +161,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
char buff[8192];
int fd, i, n;
struct ifreq *ifr=NULL;
-   struct in_addr ipaddr;
-   struct in_addr nmask;
-   char *iname;
struct ifaddrs *curif;
struct ifaddrs *lastif = NULL;
 
@@ -265,9 +259,6 @@ int rep_getifaddrs(struct ifaddrs **ifap)
int fd, i;
struct ifconf ifc;
struct ifreq *ifr=NULL;
-   struct in_addr ipaddr;
-   struct in_addr nmask;
-   char *iname;
struct ifaddrs *curif;
struct ifaddrs *lastif = NULL;
 
diff --git a/source3/client/client.c b/source3/client/client.c
index 2f9e3c0..aaa9e35 100644
--- a/source3/client/client.c
+++ b/source3/client/client.c
@@ -1784,13 +1784,13 @@ static struct file_list {
  Free a file_list structure.
 /
 
-static void free_file_list (struct file_list *list_head)
+static void free_file_list (struct file_list *l_head)
 {
struct file_list *list, *next;
 
-   for (list = list_head; list; list = next) {
+   for (list = l_head; list; list = next) {
next = list->next;
-   DLIST_REMOVE(list_head, list);
+   DLIST_REMOVE(l_head, list);
SAFE_FREE(list->file_path);
SAFE_FREE(list);
}
diff --git a/source3/lib/ldap_debug_handler.c b/source3/lib/ldap_debug_handler.c
index 2181ff0..98623d1 100644
--- a/source3/lib/ldap_debug_handler.c
+++ b/source3/lib/ldap_debug_handler.c
@@ -19,13 +19,11 @@
 
 #include "includes.h"
 
-#if HAVE_LDAP
-
+#if defined(HAVE_LDAP) && defined(HAVE_LBER_LOG_PRINT_FN)
 static void samba_ldap_log_print_fn(LDAP_CONST char *data)
 {
DEBUG(lp_ldap_debug_threshold(), ("[LDAP] %s", data));
 }
-
 #endif
 
 void init_ldap_debugging(void)
diff --git a/source3/lib/smbldap.c b/source3/lib/smbldap.c
index f0561a5..e24d358 100644
--- a/source3/lib/smbldap.c
+++ b/source3/lib/smbldap.c
@@ -581,7 +581,9 @@ static void smbldap_store_state(LDAP *ld, struct 
smbldap_state *smbldap_state)
 
 int smb_ldap_start_tls(LDAP *ldap_struct, int version)
 { 
+#ifdef LDAP_OPT_X_TLS
int rc;
+#endif

if (lp_ldap_ssl() != LDAP_SSL_START_TLS) {
return LDAP_SUCCESS;
diff --git a/source3/lib/system.c b/source3/lib/system.c
index ed6..8bdc9fa 100644
--- a/source3/lib/system.c
+++ b/source3/lib/system.c
@@ -2008,7 +2008,6 @@ static ssize_t solaris_read_xattr(int attrfd, void 
*value, size_t size)
 static ssize_t solaris_list_xattr(int attrdirfd, char *list, size_t size)
 {
ssize_t len = 0;
-   int stop = 0;
DIR *dirp;
struct dirent *de;
int newfd = dup(attrdirfd);
@@ -2080,7 +2079,7 @@ static int solaris_openat(int fildes, const char *path, 
int oflag, mode_t mode)
 {
int filedes = openat(fildes, path, oflag, mode);
if (filedes == -1) {
-   DEBUG(10,("openat FAILED: fd: %s, path: %s, errno: 
%s\n",filedes,path,strerror(errno)));
+   DEBUG(10,("opena

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1106-gbcd6e5e

2009-02-23 Thread Günther Deschner
The branch, master has been updated
   via  bcd6e5ec3315b14cedf7437a70c34d233ded082e (commit)
  from  3e796103b28f1279bdaa481b7d5c4447d62683bb (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit bcd6e5ec3315b14cedf7437a70c34d233ded082e
Author: Günther Deschner 
Date:   Mon Feb 23 11:43:32 2009 +0100

s3-spoolss: fix notify_printer_status_byname.

This took me almost a week to find, so here a little longer explanation:

When a windows client registers printer *status* change notifies using
spoolss_RemoteFindFirstChangeNotify, it registers them to a print server 
handle,
not a printer handle. We were then correctly monitoring the printer status
changes but were sending out the spoolss_RouterReplyPrinterEx via the 
back-channel
connection with job_id set to 0 (which we only may do for monitored printer
change status notifies on printer handlers, not print server handles). 
Windows
was then showing a new empty dummy printer icon in the explorer as it cannot
route the notify event to the approriate local handle. It also discarded the
content of the notify event message of course. With this, printer change 
notify for
pausing, resuming and purging printers nicely works again here.

Jerry, Tim and all other printing gurus, please check.

Guenther

---

Summary of changes:
 source3/printing/notify.c |4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/printing/notify.c b/source3/printing/notify.c
index d478b86..e19212e 100644
--- a/source3/printing/notify.c
+++ b/source3/printing/notify.c
@@ -397,8 +397,10 @@ void notify_printer_status_byname(const char *sharename, 
uint32 status)
 {
/* Printer status stored in value1 */
 
+   int snum = print_queue_snum(sharename);
+
send_notify_field_values(sharename, PRINTER_NOTIFY_TYPE, 
-PRINTER_NOTIFY_STATUS, 0, 
+PRINTER_NOTIFY_STATUS, snum,
 status, 0, 0);
 }
 


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1105-g3e79610

2009-02-23 Thread Günther Deschner
The branch, master has been updated
   via  3e796103b28f1279bdaa481b7d5c4447d62683bb (commit)
   via  6532fea2c8469c30a187cc6d4fc36b3b32ec2dd5 (commit)
   via  b8b3a6f1fc3dd10820906118264943860a73c1c4 (commit)
   via  0449d5c285c4f2f64d1aae3654322997e65ceade (commit)
  from  1a9bb33a7db393aff970619f20490e755f0d282b (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 3e796103b28f1279bdaa481b7d5c4447d62683bb
Author: Günther Deschner 
Date:   Tue Feb 24 01:03:19 2009 +0100

s3: re-run make samba3-idl.

Guenther

commit 6532fea2c8469c30a187cc6d4fc36b3b32ec2dd5
Author: Günther Deschner 
Date:   Tue Feb 24 00:47:32 2009 +0100

spoolss: add push,pull helper for spoolss_DriverInfo101.

Guenther

commit b8b3a6f1fc3dd10820906118264943860a73c1c4
Author: Günther Deschner 
Date:   Tue Feb 24 00:45:25 2009 +0100

spoolss: add spoolss_DriverInfo101 to IDL.

Note that the size_is of the spoolss_DriverFileInfo is not reflected on the 
ndr.
It is just used as pidl cannot handle a relative pointer to a static array 
of
structs.

Guenther

commit 0449d5c285c4f2f64d1aae3654322997e65ceade
Author: Günther Deschner 
Date:   Mon Feb 23 22:58:33 2009 +0100

spoolss: generate size functions for printer driver structs.

Guenther

---

Summary of changes:
 librpc/gen_ndr/ndr_spoolss.c |  312 +---
 librpc/gen_ndr/ndr_spoolss.h |   31 +++
 librpc/gen_ndr/spoolss.h |   65 +-
 librpc/idl/spoolss.idl   |   56 -
 librpc/ndr/ndr_spoolss_buf.c |  478 ++
 librpc/ndr/ndr_spoolss_buf.h |3 +
 6 files changed, 894 insertions(+), 51 deletions(-)


Changeset truncated at 500 lines:

diff --git a/librpc/gen_ndr/ndr_spoolss.c b/librpc/gen_ndr/ndr_spoolss.c
index 242041f..3e210b2 100644
--- a/librpc/gen_ndr/ndr_spoolss.c
+++ b/librpc/gen_ndr/ndr_spoolss.c
@@ -4796,13 +4796,13 @@ _PUBLIC_ void ndr_print_spoolss_AddDriverInfo1(struct 
ndr_print *ndr, const char
ndr->depth--;
 }
 
-static enum ndr_err_code ndr_push_spoolss_DriverOSVersion(struct ndr_push 
*ndr, int ndr_flags, enum spoolss_DriverOSVersion r)
+_PUBLIC_ enum ndr_err_code ndr_push_spoolss_DriverOSVersion(struct ndr_push 
*ndr, int ndr_flags, enum spoolss_DriverOSVersion r)
 {
NDR_CHECK(ndr_push_uint32(ndr, NDR_SCALARS, r));
return NDR_ERR_SUCCESS;
 }
 
-static enum ndr_err_code ndr_pull_spoolss_DriverOSVersion(struct ndr_pull 
*ndr, int ndr_flags, enum spoolss_DriverOSVersion *r)
+_PUBLIC_ enum ndr_err_code ndr_pull_spoolss_DriverOSVersion(struct ndr_pull 
*ndr, int ndr_flags, enum spoolss_DriverOSVersion *r)
 {
uint32_t v;
NDR_CHECK(ndr_pull_uint32(ndr, NDR_SCALARS, &v));
@@ -5704,7 +5704,7 @@ static enum ndr_err_code 
ndr_push_spoolss_AddDriverInfo6(struct ndr_push *ndr, i
NDR_CHECK(ndr_push_unique_ptr(ndr, r->dependent_files));
NDR_CHECK(ndr_push_uint32(ndr, NDR_SCALARS, 
((ndr_size_spoolss_StringArray(r->previous_names, ndr->iconv_convenience, 
ndr->flags) - 4) / 2)));
NDR_CHECK(ndr_push_unique_ptr(ndr, r->previous_names));
-   NDR_CHECK(ndr_push_NTTIME(ndr, NDR_SCALARS, r->driver_data));
+   NDR_CHECK(ndr_push_NTTIME(ndr, NDR_SCALARS, r->driver_date));
NDR_CHECK(ndr_push_hyper(ndr, NDR_SCALARS, r->driver_version));
NDR_CHECK(ndr_push_unique_ptr(ndr, r->manufacturer_name));
NDR_CHECK(ndr_push_unique_ptr(ndr, r->manufacturer_url));
@@ -5889,7 +5889,7 @@ static enum ndr_err_code 
ndr_pull_spoolss_AddDriverInfo6(struct ndr_pull *ndr, i
} else {
r->previous_names = NULL;
}
-   NDR_CHECK(ndr_pull_NTTIME(ndr, NDR_SCALARS, &r->driver_data));
+   NDR_CHECK(ndr_pull_NTTIME(ndr, NDR_SCALARS, &r->driver_date));
NDR_CHECK(ndr_pull_hyper(ndr, NDR_SCALARS, &r->driver_version));
NDR_CHECK(ndr_pull_generic_ptr(ndr, &_ptr_manufacturer_name));
if (_ptr_manufacturer_name) {
@@ -6144,7 +6144,7 @@ _PUBLIC_ void ndr_print_spoolss_AddDriverInfo6(struct 
ndr_print *ndr, const char
ndr_print_spoolss_StringArray(ndr, "previous_names", 
r->previous_names);
}
ndr->depth--;
-   ndr_print_NTTIME(ndr, "driver_data", r->driver_data);
+   ndr_print_NTTIME(ndr, "driver_date", r->driver_date);
ndr_print_hyper(ndr, "driver_version", r->driver_version);
ndr_print_ptr(ndr, "manufacturer_name", r->manufacturer_name);
ndr->depth++;
@@ -6190,7 +6190,7 @@ static enum ndr_err_code 
ndr_push_spoolss_AddDriverInfo8(struct ndr_push *ndr, i
NDR_CHECK(ndr_push_unique_ptr(ndr, r->dependent_files));
NDR_CHECK(ndr_push_uint32(ndr, N

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1101-g1a9bb33

2009-02-23 Thread Günther Deschner
The branch, master has been updated
   via  1a9bb33a7db393aff970619f20490e755f0d282b (commit)
  from  2033b44c3f0872d98d8144a9fbf6d09fbde196e5 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 1a9bb33a7db393aff970619f20490e755f0d282b
Author: Günther Deschner 
Date:   Mon Feb 23 22:59:42 2009 +0100

error-codes: add WERR_INVALID_USER_BUFFER.

Guenther

---

Summary of changes:
 libcli/util/doserr.c |1 +
 libcli/util/werror.h |1 +
 2 files changed, 2 insertions(+), 0 deletions(-)


Changeset truncated at 500 lines:

diff --git a/libcli/util/doserr.c b/libcli/util/doserr.c
index 160e7bc..226c2f9 100644
--- a/libcli/util/doserr.c
+++ b/libcli/util/doserr.c
@@ -135,6 +135,7 @@ static const struct werror_code_struct dos_errs[] =
{ "WERR_INVALID_FLAGS", WERR_INVALID_FLAGS },
{ "WERR_NOT_FOUND", WERR_NOT_FOUND },
{ "WERR_SERVER_UNAVAILABLE", WERR_SERVER_UNAVAILABLE },
+   { "WERR_INVALID_USER_BUFFER", WERR_INVALID_USER_BUFFER },
{ "WERR_NO_TRUST_SAM_ACCOUNT", WERR_NO_TRUST_SAM_ACCOUNT },
{ "WERR_CLASS_NOT_REGISTERED", WERR_CLASS_NOT_REGISTERED },
{ "WERR_NO_SHUTDOWN_IN_PROGRESS", WERR_NO_SHUTDOWN_IN_PROGRESS },
diff --git a/libcli/util/werror.h b/libcli/util/werror.h
index d22516a..4b34b14 100644
--- a/libcli/util/werror.h
+++ b/libcli/util/werror.h
@@ -136,6 +136,7 @@ typedef uint32_t WERROR;
 #define WERR_TIME_SKEW W_ERROR(1398)
 #define WERR_EVENTLOG_FILE_CORRUPT W_ERROR(1500)
 #define WERR_SERVER_UNAVAILABLE W_ERROR(1722)
+#define WERR_INVALID_USER_BUFFER W_ERROR(1784)
 #define WERR_NO_TRUST_SAM_ACCOUNT W_ERROR(1787)
 #define WERR_INVALID_FORM_NAME W_ERROR(1902)
 #define WERR_INVALID_FORM_SIZE W_ERROR(1903)


-- 
Samba Shared Repository


Build status as of Tue Feb 24 00:00:02 2009

2009-02-23 Thread build
URL: http://build.samba.org/

--- /home/build/master/cache/broken_results.txt.old 2009-02-23 
00:00:28.0 +
+++ /home/build/master/cache/broken_results.txt 2009-02-24 00:00:26.0 
+
@@ -1,4 +1,4 @@
-Build status as of Mon Feb 23 00:00:01 2009
+Build status as of Tue Feb 24 00:00:02 2009
 
 Build counts:
 Tree Total  Broken Panic 
@@ -6,18 +6,18 @@
 ccache   29 5  0 
 ctdb 0  0  0 
 distcc   0  0  0 
-ldb  29 28 0 
+ldb  29 29 0 
 libreplace   29 11 0 
-lorikeet-heimdal 25 14 0 
+lorikeet-heimdal 26 14 0 
 pidl 20 3  0 
 ppp  12 0  0 
-rsync29 9  0 
+rsync28 8  0 
 samba-docs   0  0  0 
 samba-gtk5  5  0 
-samba_3_X_devel 28 27 1 
+samba_3_X_devel 28 28 2 
 samba_3_X_test 27 25 3 
-samba_4_0_test 27 26 1 
+samba_4_0_test 29 26 1 
 smb-build28 6  0 
 talloc   29 28 0 
-tdb  27 9  0 
+tdb  27 8  0 
 


[SCM] Samba Shared Repository - branch v3-3-test updated - release-3-2-0pre2-5006-g6306dd0

2009-02-23 Thread Jeremy Allison
The branch, v3-3-test has been updated
   via  6306dd0cab617930176fdde91641344ef403429b (commit)
  from  d32b6d5afd6437544c0fc42681351552d89907dc (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-test


- Log -
commit 6306dd0cab617930176fdde91641344ef403429b
Author: Jeremy Allison 
Date:   Mon Feb 23 15:42:52 2009 -0800

More warning fixes for Solaris.
Jeremy.

---

Summary of changes:
 source/libgpo/gpo_reg.c   |8 
 source/modules/vfs_solarisacl.c   |9 +
 source/rpc_server/srv_svcctl_nt.c |6 +++---
 source/services/services_db.c |6 +++---
 source/utils/profiles.c   |   30 +++---
 source/utils/sharesec.c   |6 +++---
 6 files changed, 33 insertions(+), 32 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source/libgpo/gpo_reg.c b/source/libgpo/gpo_reg.c
index d493150..9b694b4 100644
--- a/source/libgpo/gpo_reg.c
+++ b/source/libgpo/gpo_reg.c
@@ -691,7 +691,7 @@ static WERROR gp_reg_generate_sd(TALLOC_CTX *mem_ctx,
SEC_ACE ace[6];
uint32_t mask;
 
-   SEC_ACL *acl = NULL;
+   SEC_ACL *theacl = NULL;
 
uint8_t inherit_flags;
 
@@ -735,15 +735,15 @@ static WERROR gp_reg_generate_sd(TALLOC_CTX *mem_ctx,
 SEC_ACE_TYPE_ACCESS_ALLOWED,
 mask, inherit_flags);
 
-   acl = make_sec_acl(mem_ctx, NT4_ACL_REVISION, 6, ace);
-   W_ERROR_HAVE_NO_MEMORY(acl);
+   theacl = make_sec_acl(mem_ctx, NT4_ACL_REVISION, 6, ace);
+   W_ERROR_HAVE_NO_MEMORY(theacl);
 
*sd = make_sec_desc(mem_ctx, SEC_DESC_REVISION,
SEC_DESC_SELF_RELATIVE |
SEC_DESC_DACL_AUTO_INHERITED | /* really ? */
SEC_DESC_DACL_AUTO_INHERIT_REQ, /* really ? */
NULL, NULL, NULL,
-   acl, sd_size);
+   theacl, sd_size);
W_ERROR_HAVE_NO_MEMORY(*sd);
 
return WERR_OK;
diff --git a/source/modules/vfs_solarisacl.c b/source/modules/vfs_solarisacl.c
index 7bdfe84..cafb077 100644
--- a/source/modules/vfs_solarisacl.c
+++ b/source/modules/vfs_solarisacl.c
@@ -51,11 +51,12 @@ static bool solaris_add_to_acl(SOLARIS_ACL_T *solaris_acl, 
int *count,
 static bool solaris_acl_get_file(const char *name, SOLARIS_ACL_T *solarisacl, 
int *count);
 static bool solaris_acl_get_fd(int fd, SOLARIS_ACL_T *solarisacl, int *count);
-static bool solaris_acl_sort(SOLARIS_ACL_T acl, int count);
+static bool solaris_acl_sort(SOLARIS_ACL_T theacl, int count);
 static SMB_ACL_PERM_T solaris_perm_to_smb_perm(const SOLARIS_PERM_T perm);
 static SOLARIS_PERM_T smb_perm_to_solaris_perm(const SMB_ACL_PERM_T perm);
+#if 0
 static bool solaris_acl_check(SOLARIS_ACL_T solaris_acl, int count);
-
+#endif
 
 /* public functions - the api */
 
@@ -347,7 +348,6 @@ static bool smb_acl_to_solaris_acl(SMB_ACL_T smb_acl,
 {
bool ret = False;
int i;
-   int check_which, check_rc;
 
DEBUG(10, ("entering smb_acl_to_solaris_acl\n"));

@@ -717,6 +717,7 @@ static bool solaris_acl_sort(SOLARIS_ACL_T solaris_acl, int 
count)
return True;
 }
 
+#if 0
 /*
  * acl check function:
  *   unused at the moment but could be used to get more
@@ -746,7 +747,7 @@ static bool solaris_acl_check(SOLARIS_ACL_T solaris_acl, 
int count)
}
return True;
 }
-
+#endif
 
 /* VFS operations structure */
 
diff --git a/source/rpc_server/srv_svcctl_nt.c 
b/source/rpc_server/srv_svcctl_nt.c
index dbe0981..226a390 100644
--- a/source/rpc_server/srv_svcctl_nt.c
+++ b/source/rpc_server/srv_svcctl_nt.c
@@ -139,7 +139,7 @@ static SEC_DESC* construct_scm_sd( TALLOC_CTX *ctx )
SEC_ACE ace[2];
size_t i = 0;
SEC_DESC *sd;
-   SEC_ACL *acl;
+   SEC_ACL *theacl;
size_t sd_size;
 
/* basic access for Everyone */
@@ -155,12 +155,12 @@ static SEC_DESC* construct_scm_sd( TALLOC_CTX *ctx )
 
/* create the security descriptor */
 
-   if ( !(acl = make_sec_acl(ctx, NT4_ACL_REVISION, i, ace)) )
+   if ( !(theacl = make_sec_acl(ctx, NT4_ACL_REVISION, i, ace)) )
return NULL;
 
if ( !(sd = make_sec_desc(ctx, SECURITY_DESCRIPTOR_REVISION_1,
  SEC_DESC_SELF_RELATIVE, NULL, NULL, NULL,
- acl, &sd_size)) )
+ theacl, &sd_size)) )
return NULL;
 
return sd;
diff --git a/source/services/services_db.c b/source/services/services_db.c
index 0f5264b..35c071f 100644
--- a/source/services/services_db.c
+++ b/source/services/services_db.c
@@ -91,7 +91,7 @@ static SEC_DESC* construct_service_sd( TALLOC_CTX *ctx )
SEC_ACE ace[4];
size_t i = 0;
SEC_DESC *s

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1100-g2033b44

2009-02-23 Thread Jeremy Allison
The branch, master has been updated
   via  2033b44c3f0872d98d8144a9fbf6d09fbde196e5 (commit)
  from  0b62cdbed0867d0712821953700062727f668c65 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 2033b44c3f0872d98d8144a9fbf6d09fbde196e5
Author: Jeremy Allison 
Date:   Mon Feb 23 15:44:34 2009 -0800

More warning fixes for Solaris.
Jeremy.

---

Summary of changes:
 source3/libgpo/gpo_reg.c   |8 
 source3/modules/vfs_solarisacl.c   |9 +
 source3/rpc_server/srv_svcctl_nt.c |6 +++---
 source3/services/services_db.c |6 +++---
 source3/utils/profiles.c   |   30 +++---
 source3/utils/sharesec.c   |6 +++---
 6 files changed, 33 insertions(+), 32 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/libgpo/gpo_reg.c b/source3/libgpo/gpo_reg.c
index 3d385de..9367bca 100644
--- a/source3/libgpo/gpo_reg.c
+++ b/source3/libgpo/gpo_reg.c
@@ -691,7 +691,7 @@ static WERROR gp_reg_generate_sd(TALLOC_CTX *mem_ctx,
SEC_ACE ace[6];
uint32_t mask;
 
-   SEC_ACL *acl = NULL;
+   SEC_ACL *theacl = NULL;
 
uint8_t inherit_flags;
 
@@ -735,15 +735,15 @@ static WERROR gp_reg_generate_sd(TALLOC_CTX *mem_ctx,
 SEC_ACE_TYPE_ACCESS_ALLOWED,
 mask, inherit_flags);
 
-   acl = make_sec_acl(mem_ctx, NT4_ACL_REVISION, 6, ace);
-   W_ERROR_HAVE_NO_MEMORY(acl);
+   theacl = make_sec_acl(mem_ctx, NT4_ACL_REVISION, 6, ace);
+   W_ERROR_HAVE_NO_MEMORY(theacl);
 
*sd = make_sec_desc(mem_ctx, SEC_DESC_REVISION,
SEC_DESC_SELF_RELATIVE |
SEC_DESC_DACL_AUTO_INHERITED | /* really ? */
SEC_DESC_DACL_AUTO_INHERIT_REQ, /* really ? */
NULL, NULL, NULL,
-   acl, sd_size);
+   theacl, sd_size);
W_ERROR_HAVE_NO_MEMORY(*sd);
 
return WERR_OK;
diff --git a/source3/modules/vfs_solarisacl.c b/source3/modules/vfs_solarisacl.c
index 7bdfe84..cafb077 100644
--- a/source3/modules/vfs_solarisacl.c
+++ b/source3/modules/vfs_solarisacl.c
@@ -51,11 +51,12 @@ static bool solaris_add_to_acl(SOLARIS_ACL_T *solaris_acl, 
int *count,
 static bool solaris_acl_get_file(const char *name, SOLARIS_ACL_T *solarisacl, 
int *count);
 static bool solaris_acl_get_fd(int fd, SOLARIS_ACL_T *solarisacl, int *count);
-static bool solaris_acl_sort(SOLARIS_ACL_T acl, int count);
+static bool solaris_acl_sort(SOLARIS_ACL_T theacl, int count);
 static SMB_ACL_PERM_T solaris_perm_to_smb_perm(const SOLARIS_PERM_T perm);
 static SOLARIS_PERM_T smb_perm_to_solaris_perm(const SMB_ACL_PERM_T perm);
+#if 0
 static bool solaris_acl_check(SOLARIS_ACL_T solaris_acl, int count);
-
+#endif
 
 /* public functions - the api */
 
@@ -347,7 +348,6 @@ static bool smb_acl_to_solaris_acl(SMB_ACL_T smb_acl,
 {
bool ret = False;
int i;
-   int check_which, check_rc;
 
DEBUG(10, ("entering smb_acl_to_solaris_acl\n"));

@@ -717,6 +717,7 @@ static bool solaris_acl_sort(SOLARIS_ACL_T solaris_acl, int 
count)
return True;
 }
 
+#if 0
 /*
  * acl check function:
  *   unused at the moment but could be used to get more
@@ -746,7 +747,7 @@ static bool solaris_acl_check(SOLARIS_ACL_T solaris_acl, 
int count)
}
return True;
 }
-
+#endif
 
 /* VFS operations structure */
 
diff --git a/source3/rpc_server/srv_svcctl_nt.c 
b/source3/rpc_server/srv_svcctl_nt.c
index 33bf3d0..b90a189 100644
--- a/source3/rpc_server/srv_svcctl_nt.c
+++ b/source3/rpc_server/srv_svcctl_nt.c
@@ -139,7 +139,7 @@ static SEC_DESC* construct_scm_sd( TALLOC_CTX *ctx )
SEC_ACE ace[2];
size_t i = 0;
SEC_DESC *sd;
-   SEC_ACL *acl;
+   SEC_ACL *theacl;
size_t sd_size;
 
/* basic access for Everyone */
@@ -155,12 +155,12 @@ static SEC_DESC* construct_scm_sd( TALLOC_CTX *ctx )
 
/* create the security descriptor */
 
-   if ( !(acl = make_sec_acl(ctx, NT4_ACL_REVISION, i, ace)) )
+   if ( !(theacl = make_sec_acl(ctx, NT4_ACL_REVISION, i, ace)) )
return NULL;
 
if ( !(sd = make_sec_desc(ctx, SECURITY_DESCRIPTOR_REVISION_1,
  SEC_DESC_SELF_RELATIVE, NULL, NULL, NULL,
- acl, &sd_size)) )
+ theacl, &sd_size)) )
return NULL;
 
return sd;
diff --git a/source3/services/services_db.c b/source3/services/services_db.c
index 6d1b5d5..ef975cf 100644
--- a/source3/services/services_db.c
+++ b/source3/services/services_db.c
@@ -91,7 +91,7 @@ static SEC_DESC* construct_service_sd( TALLOC_CTX *ctx )
SEC_ACE ace[4];
size_t i = 0;
   

[SCM] Samba Shared Repository - branch v3-3-test updated - release-3-2-0pre2-5005-gd32b6d5

2009-02-23 Thread Jeremy Allison
The branch, v3-3-test has been updated
   via  d32b6d5afd6437544c0fc42681351552d89907dc (commit)
  from  e5f5284cc036217d20d5ca690e14d87ba0ebccaa (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-test


- Log -
commit d32b6d5afd6437544c0fc42681351552d89907dc
Author: Jeremy Allison 
Date:   Mon Feb 23 15:02:52 2009 -0800

Quieten down a boatload of shadowed variable warnings on Solaris.
Makes real problems easier to spot.
Jeremy.

---

Summary of changes:
 source/include/proto.h |2 +-
 source/librpc/ndr/ndr_sec_helper.c |8 ++--
 source/modules/nfs4_acls.c |   84 ++--
 source/modules/nfs4_acls.h |   10 ++--
 source/registry/reg_dispatcher.c   |8 ++--
 5 files changed, 56 insertions(+), 56 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source/include/proto.h b/source/include/proto.h
index edb0009..981a0ee 100644
--- a/source/include/proto.h
+++ b/source/include/proto.h
@@ -3979,7 +3979,7 @@ size_t ndr_size_dom_sid(const struct dom_sid *sid, int 
flags);
 size_t ndr_size_dom_sid28(const struct dom_sid *sid, int flags);
 size_t ndr_size_dom_sid0(const struct dom_sid *sid, int flags);
 size_t ndr_size_security_ace(const struct security_ace *ace, int flags);
-size_t ndr_size_security_acl(const struct security_acl *acl, int flags);
+size_t ndr_size_security_acl(const struct security_acl *theacl, int flags);
 size_t ndr_size_security_descriptor(const struct security_descriptor *sd, int 
flags);
 void ndr_print_dom_sid(struct ndr_print *ndr, const char *name, const struct 
dom_sid *sid);
 void ndr_print_dom_sid2(struct ndr_print *ndr, const char *name, const struct 
dom_sid *sid);
diff --git a/source/librpc/ndr/ndr_sec_helper.c 
b/source/librpc/ndr/ndr_sec_helper.c
index 90ede5f..72061fa 100644
--- a/source/librpc/ndr/ndr_sec_helper.c
+++ b/source/librpc/ndr/ndr_sec_helper.c
@@ -95,14 +95,14 @@ size_t ndr_size_security_ace(const struct security_ace 
*ace, int flags)
 /*
   return the wire size of a security_acl
 */
-size_t ndr_size_security_acl(const struct security_acl *acl, int flags)
+size_t ndr_size_security_acl(const struct security_acl *theacl, int flags)
 {
size_t ret;
int i;
-   if (!acl) return 0;
+   if (!theacl) return 0;
ret = 8;
-   for (i=0;inum_aces;i++) {
-   ret += ndr_size_security_ace(&acl->aces[i], flags);
+   for (i=0;inum_aces;i++) {
+   ret += ndr_size_security_ace(&theacl->aces[i], flags);
}
return ret;
 }
diff --git a/librpc/ndr/ndr_sec_helper.c b/librpc/ndr/ndr_sec_helper.c
index 8f84c02..6219470 100644
--- a/librpc/ndr/ndr_sec_helper.c
+++ b/librpc/ndr/ndr_sec_helper.c
@@ -91,14 +91,14 @@ enum ndr_err_code ndr_pull_security_ace(struct ndr_pull 
*ndr, int ndr_flags, str
 /*
   return the wire size of a security_acl
 */
-size_t ndr_size_security_acl(const struct security_acl *acl, struct 
smb_iconv_convenience *ic, int flags)
+size_t ndr_size_security_acl(const struct security_acl *theacl, struct 
smb_iconv_convenience *ic, int flags)
 {
size_t ret;
int i;
-   if (!acl) return 0;
+   if (!theacl) return 0;
ret = 8;
-   for (i=0;inum_aces;i++) {
-   ret += ndr_size_security_ace(&acl->aces[i], ic, flags);
+   for (i=0;inum_aces;i++) {
+   ret += ndr_size_security_ace(&theacl->aces[i], ic, flags);
}
return ret;
 }
diff --git a/source4/dsdb/samdb/ldb_modules/config.mk 
b/source4/dsdb/samdb/ldb_modules/config.mk
index 01f5188..583d1dc 100644
--- a/source4/dsdb/samdb/ldb_modules/config.mk
+++ b/source4/dsdb/samdb/ldb_modules/config.mk
@@ -89,7 +89,7 @@ ldb_samldb_OBJ_FILES = \
 [MODULE::ldb_samba3sam]
 SUBSYSTEM = LIBLDB
 INIT_FUNCTION = LDB_MODULE(samba3sam)
-PRIVATE_DEPENDENCIES = LIBTALLOC LIBEVENTS SMBPASSWD \
+PRIVATE_DEPENDENCIES = LIBTALLOC LIBEVENTS LIBLDB SMBPASSWD \
NSS_WRAPPER LIBSECURITY NDR_SECURITY
 # End MODULE ldb_samldb
 
@@ -102,7 +102,7 @@ ldb_samba3sam_OBJ_FILES = \
 [MODULE::ldb_simple_ldap_map]
 SUBSYSTEM = LIBLDB
 INIT_FUNCTION = LDB_MODULE(entryuuid),LDB_MODULE(nsuniqueid)
-PRIVATE_DEPENDENCIES = LIBTALLOC LIBEVENTS LIBNDR
+PRIVATE_DEPENDENCIES = LIBTALLOC LIBEVENTS LIBLDB LIBNDR
 ENABLE = YES
 ALIASES = entryuuid nsuniqueid
 # End MODULE ldb_entryuuid
diff --git a/source4/dsdb/samdb/ldb_modules/linked_attributes.c 
b/source4/dsdb/samdb/ldb_modules/linked_attributes.c
index 2365a58..4e28c8a 100644
--- a/source4/dsdb/samdb/ldb_modules/linked_attributes.c
+++ b/source4/dsdb/samdb/ldb_modules/linked_attributes.c
@@ -30,6 +30,7 @@
 
 #include "includes.h"
 #include "ldb_module.h"
+#include "dlinklist.h"
 #include "dsdb/samdb/samdb.h"
 
 struct la_op_store {
diff --git a/source4/dsdb/samdb/ldb_modules/objectclass.c 
b/source4/dsdb/samdb/ldb_modules/objectclass.c
index 0261bb3..898d913 100644
--- a/source4/dsdb/samdb/ldb_modules/objectclass.c
+++ b/source4/dsdb/samdb/ldb_modules/objectclass.c
@@ -35,6 +35,7 @@
 
 #include "includes.h"
 #include "ldb_module.h"
+#include "dlinklist.h"
 #include "dsdb/samdb/samdb.h"
 #include "librpc/ndr/libndr.h"
 #include "librpc/gen_ndr/ndr_security.h"
diff --git a/source4/dsdb/samdb/ldb_modules/ranged_results.c 
b/source4/dsdb/samdb/ldb_modules/ranged_results.c
index 8f36baa..5ce69a2 100644
--- a/source4/dsdb/samdb/ldb_modules/ranged_results.c
+++ b/source4/dsdb/samdb/ldb_modules/ranged_results.c
@@ -29,6 +29,7 @@
  *  Author: Andrew Bartlett
  */
 
+#include "includes.h"
 #include "ldb_module.h"
 
 struct rr_context {
diff --git a/source4/dsdb/samdb/ldb_modules/samba3sam.c 
b/source4/dsdb/samdb/ldb_modules/samba3sam.c
index 3f10748..59cb9de 100644
--- a/source4/dsdb/samdb/ldb_modules/samba3sam.c
+++ b/source4/dsdb/samdb/ldb_modules/samba3sam.c
@@ -6,7 +6,7 @@
 */
 
 #include "includes.h"
-#include "ldb/include/ldb_module.h"
+#include "ldb_module.h"
 #include "ldb/ldb_map/ldb_map.h"
 #include "system/passwd.h"
 

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1097-gcf7539a

2009-02-23 Thread Derrell Lipman
The branch, master has been updated
   via  cf7539abfb0f6e6956bed7a478e0cda6ab734674 (commit)
  from  ca24822234d9dc77dbe3f351d6dbab5558efac39 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit cf7539abfb0f6e6956bed7a478e0cda6ab734674
Author: Derrell Lipman 
Date:   Mon Feb 23 13:50:11 2009 -0500

Make char* parameters const

- Use const in function signatures whenever appropriate, to help prevent
  errant scribbling on users' buffers. smbc_set_credentials() always acted 
as
  if its formal parameters were const char *, and changing the formal
  declaration to specify that should not cause any change to the ABI. It is
  still allowable to pass a writable buffer to a function which specifies 
that
  it will not write to the buffer.

  I'm making this change only in master.

Derrell

---

Summary of changes:
 source3/include/libsmbclient.h  |8 
 source3/libsmb/libsmb_context.c |   22 ++
 2 files changed, 10 insertions(+), 20 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/libsmbclient.h b/source3/include/libsmbclient.h
index 8c642b1..869aeb6 100644
--- a/source3/include/libsmbclient.h
+++ b/source3/include/libsmbclient.h
@@ -2677,11 +2677,11 @@ smbc_version(void);
  */
 
 void
-smbc_set_credentials(char *workgroup,
- char *user,
- char *password,
+smbc_set_credentials(const char *workgroup,
+ const char *user,
+ const char *password,
  smbc_bool use_kerberos,
- char *signing_state);
+ const char *signing_state);
 
 /*
  * Wrapper around smbc_set_credentials.
diff --git a/source3/libsmb/libsmb_context.c b/source3/libsmb/libsmb_context.c
index c7c9903..4c12d18 100644
--- a/source3/libsmb/libsmb_context.c
+++ b/source3/libsmb/libsmb_context.c
@@ -630,11 +630,11 @@ smbc_version(void)
  * Set the credentials so DFS will work when following referrals.
  */
 void
-smbc_set_credentials(char *workgroup,
- char *user,
- char *password,
+smbc_set_credentials(const char *workgroup,
+ const char *user,
+ const char *password,
  smbc_bool use_kerberos,
- char *signing_state)
+ const char *signing_state)
 {
 struct user_auth_info *auth_info;
 
@@ -681,18 +681,8 @@ void smbc_set_credentials_with_fallback(SMBCCTX *context,
signing_state = "force";
}
 
-   /* Using CONST_DISCARD here is ugly, but
-* we know that smbc_set_credentials() doesn't
-* actually modify the strings, and should have
-* been const from the start. We're constrained
-* by the ABI here.
-*/
-
-   smbc_set_credentials(CONST_DISCARD(char *,workgroup),
-CONST_DISCARD(char *,user),
-CONST_DISCARD(char *,password),
-use_kerberos,
-CONST_DISCARD(char *,signing_state));
+   smbc_set_credentials(workgroup, user, password,
+ use_kerberos, signing_state);
 
if (smbc_getOptionFallbackAfterKerberos(context)) {
cli_cm_set_fallback_after_kerberos();


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1096-gca24822

2009-02-23 Thread Simo Sorce
The branch, master has been updated
   via  ca24822234d9dc77dbe3f351d6dbab5558efac39 (commit)
   via  689b8f5bb36a003756ee41787487237eef48cfab (commit)
  from  fda0158c14b97a54a911bb87ffc0ebb7c5729138 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit ca24822234d9dc77dbe3f351d6dbab5558efac39
Author: Simo Sorce 
Date:   Mon Feb 23 13:33:39 2009 -0500

Fix GDB_PROVISION mode

commit 689b8f5bb36a003756ee41787487237eef48cfab
Author: Simo Sorce 
Date:   Sun Feb 22 01:50:49 2009 -0500

Make all transactions nested in ldb. The current samba4 code expects this
behavior anyway, and given we can only have one transaction active per
ldb context this is the only sane model we can support.

Fix ldb_tdb transactions, we could return back with an error with neither
committing nor canceling the actual tdb transaction in some error paths
within the ltdb commit and cancel transaction paths.

Added also some debugging to trace what was going on.

---

Summary of changes:
 selftest/target/Samba4.pm |2 +-
 source4/lib/ldb/common/ldb.c  |  132 
 source4/lib/ldb/ldb_tdb/ldb_tdb.c |2 +
 3 files changed, 76 insertions(+), 60 deletions(-)


Changeset truncated at 500 lines:

diff --git a/selftest/target/Samba4.pm b/selftest/target/Samba4.pm
index 7264ddb..09138cf 100644
--- a/selftest/target/Samba4.pm
+++ b/selftest/target/Samba4.pm
@@ -578,7 +578,7 @@ sub provision_raw_prepare($$$)
push (@provision_options, 
"NSS_WRAPPER_PASSWD=\"$ctx->{nsswrap_passwd}\"");
push (@provision_options, 
"NSS_WRAPPER_GROUP=\"$ctx->{nsswrap_group}\"");
if (defined($ENV{GDB_PROVISION})) {
-   push (@provision_options, "gdb --args python");
+   push (@provision_options, "gdb --args");
}
if (defined($ENV{VALGRIND_PROVISION})) {
push (@provision_options, "valgrind");
diff --git a/source4/lib/ldb/common/ldb.c b/source4/lib/ldb/common/ldb.c
index 2fb5a8f..f1b28b6 100644
--- a/source4/lib/ldb/common/ldb.c
+++ b/source4/lib/ldb/common/ldb.c
@@ -34,6 +34,19 @@
 
 #include "ldb_private.h"
 
+static int ldb_context_destructor(void *ptr)
+{
+   struct ldb_context *ldb = talloc_get_type(ptr, struct ldb_context);
+
+   if (ldb->transaction_active) {
+   ldb_debug(ldb, LDB_DEBUG_FATAL,
+ "A transaction is still active in ldb context [%p]",
+ ldb);
+   }
+
+   return 0;
+}
+
 /*
initialise a ldb context
The mem_ctx is required
@@ -65,6 +78,8 @@ struct ldb_context *ldb_init(TALLOC_CTX *mem_ctx, struct 
tevent_context *ev_ctx)
/* TODO: get timeout from options if available there */
ldb->default_timeout = 300; /* set default to 5 minutes */
 
+   talloc_set_destructor((TALLOC_CTX *)ldb, ldb_context_destructor);
+
return ldb;
 }
 
@@ -242,10 +257,24 @@ void ldb_reset_err_string(struct ldb_context *ldb)
 /*
   start a transaction
 */
-static int ldb_transaction_start_internal(struct ldb_context *ldb)
+int ldb_transaction_start(struct ldb_context *ldb)
 {
struct ldb_module *module;
int status;
+
+   ldb_debug(ldb, LDB_DEBUG_TRACE,
+ "start ldb transaction (nesting: %d)",
+ ldb->transaction_active);
+
+   /* explicit transaction active, count nested requests */
+   if (ldb->transaction_active) {
+   ldb->transaction_active++;
+   return LDB_SUCCESS;
+   }
+
+   /* start a new transaction */
+   ldb->transaction_active++;
+
FIRST_OP(ldb, start_transaction);
 
ldb_reset_err_string(ldb);
@@ -266,10 +295,29 @@ static int ldb_transaction_start_internal(struct 
ldb_context *ldb)
 /*
   commit a transaction
 */
-static int ldb_transaction_commit_internal(struct ldb_context *ldb)
+int ldb_transaction_commit(struct ldb_context *ldb)
 {
struct ldb_module *module;
int status;
+
+   ldb->transaction_active--;
+
+   ldb_debug(ldb, LDB_DEBUG_TRACE,
+ "commit ldb transaction (nesting: %d)",
+ ldb->transaction_active);
+
+   /* commit only when all nested transactions are complete */
+   if (ldb->transaction_active > 0) {
+   return LDB_SUCCESS;
+   }
+
+   if (ldb->transaction_active < 0) {
+   ldb_debug(ldb, LDB_DEBUG_FATAL,
+ "commit called but no ldb transactions are active!");
+   ldb->transaction_active = 0;
+   return LDB_ERR_OPERATIONS_ERROR;
+   }
+
FIRST_OP(ldb, end_transaction);
 
ldb_reset_err_string(ldb);
@@ -290,10 +338,29 @@ static int ldb_transaction_commit_internal(struct 
ldb_context *ldb)
 /*
   cancel a transaction
 */
-static int ldb_trans

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1094-gfda0158

2009-02-23 Thread Günther Deschner
The branch, master has been updated
   via  fda0158c14b97a54a911bb87ffc0ebb7c5729138 (commit)
  from  443743d423f591ce388fff76c60fed23b5494d90 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit fda0158c14b97a54a911bb87ffc0ebb7c5729138
Author: Günther Deschner 
Date:   Mon Feb 23 16:39:53 2009 +0100

s3-spoolss: remove cli_spoolss_notify.c completly.

All of the spoolss change notify code uses pidl generated functions now.

Guenther

---

Summary of changes:
 source3/Makefile.in |2 +-
 source3/include/proto.h |2 -
 source3/rpc_client/cli_spoolss_notify.c |   33 ---
 3 files changed, 1 insertions(+), 36 deletions(-)
 delete mode 100644 source3/rpc_client/cli_spoolss_notify.c


Changeset truncated at 500 lines:

diff --git a/source3/Makefile.in b/source3/Makefile.in
index d4a849c..7564659 100644
--- a/source3/Makefile.in
+++ b/source3/Makefile.in
@@ -465,7 +465,7 @@ RPC_CLIENT_OBJ1 = rpc_client/cli_netlogon.o
 
 LIBMSRPC_OBJ = rpc_client/cli_lsarpc.o rpc_client/cli_samr.o \
   $(RPC_CLIENT_OBJ1) rpc_client/cli_reg.o $(RPC_CLIENT_OBJ) \
-  rpc_client/cli_spoolss.o rpc_client/cli_spoolss_notify.o  \
+  rpc_client/cli_spoolss.o \
   rpc_client/init_spoolss.o \
   rpc_client/init_samr.o \
   librpc/rpc/dcerpc.o \
diff --git a/source3/include/proto.h b/source3/include/proto.h
index 525cb3c..faf47d3 100644
--- a/source3/include/proto.h
+++ b/source3/include/proto.h
@@ -5522,8 +5522,6 @@ WERROR rpccli_spoolss_enumprinterkey(struct 
rpc_pipe_client *cli, TALLOC_CTX *me
  POLICY_HND *hnd, const char *keyname,
  uint16 **keylist, uint32 *len);
 
-/* The following definitions come from rpc_client/cli_spoolss_notify.c  */
-
 /* The following definitions come from rpc_client/init_spoolss.c  */
 
 bool init_systemtime(struct spoolss_Time *r,
diff --git a/source3/rpc_client/cli_spoolss_notify.c 
b/source3/rpc_client/cli_spoolss_notify.c
deleted file mode 100644
index 41abcd4..000
--- a/source3/rpc_client/cli_spoolss_notify.c
+++ /dev/null
@@ -1,33 +0,0 @@
-/* 
-   Unix SMB/CIFS implementation.
-   RPC pipe client
-
-   Copyright (C) Gerald Carter2001-2002,
-   Copyright (C) Tim Potter   2000-2002,
-   Copyright (C) Andrew Tridgell  1994-2000,
-   Copyright (C) Jean-Francois Micouleau  1999-2000.
-   Copyright (C) Jeremy Allison2005.
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
-   (at your option) any later version.
-   
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-   
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see .
-*/
-
-#include "includes.h"
-
-/*
- * SPOOLSS Client RPC's used by servers as the notification
- * back channel.
- */
-
-/*
- */


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1093-g443743d

2009-02-23 Thread Günther Deschner
The branch, master has been updated
   via  443743d423f591ce388fff76c60fed23b5494d90 (commit)
   via  2234984fd0a745603b3131e330234349fe428742 (commit)
   via  fc703a14928c61031589ac6cce8f2985e5fb87a9 (commit)
   via  0295008a87478a6fa1c685128fa01918102d286d (commit)
   via  ce8ca0e68a577d09b492bd226b22e9c61d35ce09 (commit)
  from  c1e76d0dd9a1a7134fa3c0012a9cbe8f51f0716c (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 443743d423f591ce388fff76c60fed23b5494d90
Author: Günther Deschner 
Date:   Tue Feb 17 00:13:24 2009 +0100

s3-spoolss: remove old SPOOL_NOTIFY_OPTION definitions.

Guenther

commit 2234984fd0a745603b3131e330234349fe428742
Author: Günther Deschner 
Date:   Mon Feb 16 23:34:12 2009 +0100

s3-spoolss: remove old spoolss_RemoteFindFirstPrinterChangeNotifyEx.

Guenther

commit fc703a14928c61031589ac6cce8f2985e5fb87a9
Author: Günther Deschner 
Date:   Thu Feb 12 14:33:26 2009 +0100

s3-spoolss: remove SPOOL_NOTIFY_INFO_DATA and SPOOL_NOTIFY_INFO alltogether.

Guenther

commit 0295008a87478a6fa1c685128fa01918102d286d
Author: Günther Deschner 
Date:   Thu Feb 12 14:28:33 2009 +0100

s3-spoolss: remove old spoolss_RouterReplyPrinterEx.

Guenther

commit ce8ca0e68a577d09b492bd226b22e9c61d35ce09
Author: Günther Deschner 
Date:   Thu Feb 12 16:21:59 2009 +0100

s3-spoolss: remove old spoolss_RouterRefreshPrinterChangeNotify.

Guenther

---

Summary of changes:
 source3/include/proto.h |   25 --
 source3/include/rpc_spoolss.h   |  121 --
 source3/rpc_client/cli_spoolss_notify.c |   86 
 source3/rpc_parse/parse_spoolss.c   |  696 ---
 4 files changed, 0 insertions(+), 928 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/proto.h b/source3/include/proto.h
index 93b4ca8..525cb3c 100644
--- a/source3/include/proto.h
+++ b/source3/include/proto.h
@@ -5524,15 +5524,6 @@ WERROR rpccli_spoolss_enumprinterkey(struct 
rpc_pipe_client *cli, TALLOC_CTX *me
 
 /* The following definitions come from rpc_client/cli_spoolss_notify.c  */
 
-WERROR rpccli_spoolss_rrpcn(struct rpc_pipe_client *cli, TALLOC_CTX *mem_ctx, 
-POLICY_HND *pol, uint32 notify_data_len,
-SPOOL_NOTIFY_INFO_DATA *notify_data,
-uint32 change_low, uint32 change_high);
-WERROR rpccli_spoolss_rffpcnex(struct rpc_pipe_client *cli, TALLOC_CTX 
*mem_ctx,
-   POLICY_HND *pol, uint32 flags, uint32 options,
-   const char *localmachine, uint32 printerlocal,
-   SPOOL_NOTIFY_OPTION *option);
-
 /* The following definitions come from rpc_client/init_spoolss.c  */
 
 bool init_systemtime(struct spoolss_Time *r,
@@ -5817,8 +5808,6 @@ bool sec_io_desc_buf(const char *desc, SEC_DESC_BUF 
**ppsdb, prs_struct *ps, int
 
 bool spoolss_io_system_time(const char *desc, prs_struct *ps, int depth, 
SYSTEMTIME *systime);
 bool make_systemtime(SYSTEMTIME *systime, struct tm *unixtime);
-bool smb_io_notify_info_data_strings(const char *desc,SPOOL_NOTIFY_INFO_DATA 
*data,
- prs_struct *ps, int depth);
 bool spool_io_user_level_1( const char *desc, prs_struct *ps, int depth, 
SPOOL_USER_1 *q_u );
 bool spoolss_io_devmode(const char *desc, prs_struct *ps, int depth, 
DEVICEMODE *devmode);
 bool make_spoolss_q_addprinterex( TALLOC_CTX *mem_ctx, SPOOL_Q_ADDPRINTEREX 
*q_u, 
@@ -5835,10 +5824,6 @@ bool 
make_spoolss_q_getprinterdata(SPOOL_Q_GETPRINTERDATA *q_u,
   const char *valuename, uint32 size);
 bool spoolss_io_q_getprinterdata(const char *desc, SPOOL_Q_GETPRINTERDATA 
*q_u, prs_struct *ps, int depth);
 bool spoolss_io_r_getprinterdata(const char *desc, SPOOL_R_GETPRINTERDATA 
*r_u, prs_struct *ps, int depth);
-bool spoolss_io_q_rffpcnex(const char *desc, SPOOL_Q_RFFPCNEX *q_u, prs_struct 
*ps, int depth);
-bool spoolss_io_r_rffpcnex(const char *desc, SPOOL_R_RFFPCNEX *r_u, prs_struct 
*ps, int depth);
-bool spoolss_io_q_rfnpcnex(const char *desc, SPOOL_Q_RFNPCNEX *q_u, prs_struct 
*ps, int depth);
-bool spoolss_io_r_rfnpcnex(const char *desc, SPOOL_R_RFNPCNEX *r_u, prs_struct 
*ps, int depth);
 bool smb_io_printer_info_0(const char *desc, RPC_BUFFER *buffer, 
PRINTER_INFO_0 *info, int depth);
 bool smb_io_printer_info_1(const char *desc, RPC_BUFFER *buffer, 
PRINTER_INFO_1 *info, int depth);
 bool smb_io_printer_info_2(const char *desc, RPC_BUFFER *buffer, 
PRINTER_INFO_2 *info, int depth);
@@ -5994,11 +5979,6 @@ void free_printer_info_5(PRINTER_INFO_5 *printer);
 void free_printer_info_6(PRINTER_INFO_6 *printer);
 void free_printer_info_7(PRINTER_INFO_7 *printer);
 void free_job_info_2(JOB_INFO_2 *job);
-bool make_spoolss_

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1088-gc1e76d0

2009-02-23 Thread Günther Deschner
The branch, master has been updated
   via  c1e76d0dd9a1a7134fa3c0012a9cbe8f51f0716c (commit)
   via  b3f6d6910850efaf6240dd01576d3794d8aec170 (commit)
   via  2efa7cf6d9b20fe20a2bd6b0e64625c5082f97f1 (commit)
   via  418691c2e7eae156b10ae29cf443e26cede92e93 (commit)
   via  9b453f9248de2fce117f029240530d199e039ce1 (commit)
   via  9af13015b256e5b0eec74e1c788c13e246cde850 (commit)
   via  5116f50eb82c76bac40c558c00db17be6b56f161 (commit)
   via  6259fac904641cdc191d866e4cd9936cc68df45e (commit)
   via  03a15f2381d467c7c4d2f504297f102806847394 (commit)
  from  00913a73c7c93f410e5e05a1825138a61705ea6e (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit c1e76d0dd9a1a7134fa3c0012a9cbe8f51f0716c
Author: Günther Deschner 
Date:   Mon Feb 16 23:33:10 2009 +0100

s3-spoolss: use pidl for _spoolss_RemoteFindFirstPrinterChangeNotifyEx.

Guenther

commit b3f6d6910850efaf6240dd01576d3794d8aec170
Author: Günther Deschner 
Date:   Tue Feb 17 00:12:21 2009 +0100

s3-spoolss: use spoolss_NotifyOption and spoolss_NotifyType instead of 
SPOOL_NOTIFY_OPTION and SPOOL_NOTIFY_OPTION_TYPE.

Guenther

commit 2efa7cf6d9b20fe20a2bd6b0e64625c5082f97f1
Author: Günther Deschner 
Date:   Mon Feb 23 13:06:04 2009 +0100

s3-spoolss: add dup_spoolss_NotifyOption.

Guenther

commit 418691c2e7eae156b10ae29cf443e26cede92e93
Author: Günther Deschner 
Date:   Fri Feb 13 12:47:32 2009 +0100

s3-spoolss: use more idl types in spoolss server.

Guenther

commit 9b453f9248de2fce117f029240530d199e039ce1
Author: Günther Deschner 
Date:   Thu Feb 12 16:38:13 2009 +0100

s3-spoolss: fix memleak of spoolss_Notify array in 
_spoolss_RouterRefreshPrinterChangeNotify.

Guenther

commit 9af13015b256e5b0eec74e1c788c13e246cde850
Author: Günther Deschner 
Date:   Thu Feb 12 00:40:37 2009 +0100

s3-spoolss: use rpccli_spoolss_RouterReplyPrinterEx.

Guenther

commit 5116f50eb82c76bac40c558c00db17be6b56f161
Author: Günther Deschner 
Date:   Thu Feb 12 14:18:28 2009 +0100

s3-spoolss: use pidl for _spoolss_RouterRefreshPrinterChangeNotify.

Guenther

commit 6259fac904641cdc191d866e4cd9936cc68df45e
Author: Günther Deschner 
Date:   Thu Feb 12 14:17:53 2009 +0100

s3-spoolss: use struct spoolss_NotifyInfo instead of SPOOL_NOTIFY_INFO.

Guenther

commit 03a15f2381d467c7c4d2f504297f102806847394
Author: Günther Deschner 
Date:   Thu Feb 12 13:59:28 2009 +0100

s3-spoolss: use struct spoolss_Notify instead of SPOOL_NOTIFY_INFO_DATA.

Guenther

---

Summary of changes:
 source3/include/nt_printing.h   |2 +-
 source3/include/proto.h |   31 +-
 source3/rpc_server/srv_spoolss.c|   47 +--
 source3/rpc_server/srv_spoolss_nt.c | 1014 ++-
 4 files changed, 429 insertions(+), 665 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/nt_printing.h b/source3/include/nt_printing.h
index 3bf51f2..43fd363 100644
--- a/source3/include/nt_printing.h
+++ b/source3/include/nt_printing.h
@@ -439,7 +439,7 @@ typedef struct _Printer{
uint32 options;
fstring localmachine;
uint32 printerlocal;
-   SPOOL_NOTIFY_OPTION *option;
+   struct spoolss_NotifyOption *option;
POLICY_HND client_hnd;
bool client_connected;
uint32 change;
diff --git a/source3/include/proto.h b/source3/include/proto.h
index 9dc9719..93b4ca8 100644
--- a/source3/include/proto.h
+++ b/source3/include/proto.h
@@ -6142,72 +6142,75 @@ WERROR set_printer_dataex( NT_PRINTER_INFO_LEVEL 
*printer, const char *key, cons
 WERROR _spoolss_getprinterdata(pipes_struct *p, SPOOL_Q_GETPRINTERDATA *q_u, 
SPOOL_R_GETPRINTERDATA *r_u);
 WERROR _spoolss_rffpcnex(pipes_struct *p, SPOOL_Q_RFFPCNEX *q_u, 
SPOOL_R_RFFPCNEX *r_u);
 void spoolss_notify_server_name(int snum,
-  SPOOL_NOTIFY_INFO_DATA *data,
+  struct spoolss_Notify *data,
   print_queue_struct *queue,
   NT_PRINTER_INFO_LEVEL *printer,
   TALLOC_CTX *mem_ctx);
 void spoolss_notify_printer_name(int snum,
-   SPOOL_NOTIFY_INFO_DATA *data,
+   struct spoolss_Notify *data,
print_queue_struct *queue,
NT_PRINTER_INFO_LEVEL *printer,
TALLOC_CTX *mem_ctx);
 void spoolss_notify_share_name(int snum,
- SPOOL_NOTIFY_INFO_DATA *data,
+ struct spoo

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1079-g00913a7

2009-02-23 Thread Volker Lendecke
The branch, master has been updated
   via  00913a73c7c93f410e5e05a1825138a61705ea6e (commit)
  from  dc0bf17ac130764f3bbdc2d07de4a0fb54a761d2 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 00913a73c7c93f410e5e05a1825138a61705ea6e
Author: Björn Jacke 
Date:   Sun Feb 22 19:46:40 2009 +0100

prefer gssapi header files from subdirectory

this fixes some compile time noise on FreeBSD 7

---

Summary of changes:
 source3/include/includes.h |6 +++---
 source3/libaddns/dns.h |6 +++---
 2 files changed, 6 insertions(+), 6 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/includes.h b/source3/include/includes.h
index 1906830..5ab5564 100644
--- a/source3/include/includes.h
+++ b/source3/include/includes.h
@@ -190,12 +190,12 @@ typedef int ber_int_t;
 #undef HAVE_LDAP
 #endif
 
-#if HAVE_GSSAPI_H
-#include 
-#elif HAVE_GSSAPI_GSSAPI_H
+#if HAVE_GSSAPI_GSSAPI_H
 #include 
 #elif HAVE_GSSAPI_GSSAPI_GENERIC_H
 #include 
+#elif HAVE_GSSAPI_H
+#include 
 #endif
 
 #if HAVE_COM_ERR_H
diff --git a/source3/libaddns/dns.h b/source3/libaddns/dns.h
index 42662a2..57a9b6a 100644
--- a/source3/libaddns/dns.h
+++ b/source3/libaddns/dns.h
@@ -81,12 +81,12 @@
 #include 
 #endif
 
-#if HAVE_GSSAPI_H
-#include 
-#elif HAVE_GSSAPI_GSSAPI_H
+#if HAVE_GSSAPI_GSSAPI_H
 #include 
 #elif HAVE_GSSAPI_GSSAPI_GENERIC_H
 #include 
+#elif HAVE_GSSAPI_H
+#include 
 #endif
 
 #if defined(HAVE_GSSAPI_H) || defined(HAVE_GSSAPI_GSSAPI_H) || 
defined(HAVE_GSSAPI_GSSAPI_GENERIC_H)


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1078-gdc0bf17

2009-02-23 Thread Günther Deschner
The branch, master has been updated
   via  dc0bf17ac130764f3bbdc2d07de4a0fb54a761d2 (commit)
   via  e2ab5a155cd8b20d1dce91fa2f31d840c673a3b6 (commit)
   via  db400032abc48baafaef87d72e6498505642bf34 (commit)
   via  672eb22bc1ee6ee7d3372655f0847f676727643a (commit)
  from  cd6ae0de52164dd6f50b3614f2511acb3eb15993 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit dc0bf17ac130764f3bbdc2d07de4a0fb54a761d2
Author: Günther Deschner 
Date:   Mon Feb 23 10:29:46 2009 +0100

s3-rpcclient: use correct clientname in 
spoolss_RemoteFindFirstPrinterChangeNotifyEx command.

Guenther

commit e2ab5a155cd8b20d1dce91fa2f31d840c673a3b6
Author: Günther Deschner 
Date:   Mon Feb 23 12:47:53 2009 +0100

s3: re-run make samba3-idl.

Guenther

commit db400032abc48baafaef87d72e6498505642bf34
Author: Günther Deschner 
Date:   Mon Feb 23 11:50:27 2009 +0100

spoolss: spoolss_NotifyData contains a devmode container, not devmode 
pointer.

Guenther

commit 672eb22bc1ee6ee7d3372655f0847f676727643a
Author: Günther Deschner 
Date:   Sat Feb 21 23:11:49 2009 +0100

spoolss: fix some PRINTER_CHANGE_ defines (and add a new windows 7 flag).

Guenther

---

Summary of changes:
 librpc/gen_ndr/ndr_spoolss.c|   30 ++
 librpc/gen_ndr/spoolss.h|   11 ++-
 librpc/idl/spoolss.idl  |   19 +++
 source3/rpcclient/cmd_spoolss.c |9 -
 4 files changed, 27 insertions(+), 42 deletions(-)


Changeset truncated at 500 lines:

diff --git a/librpc/gen_ndr/ndr_spoolss.c b/librpc/gen_ndr/ndr_spoolss.c
index b0d5366..242041f 100644
--- a/librpc/gen_ndr/ndr_spoolss.c
+++ b/librpc/gen_ndr/ndr_spoolss.c
@@ -13053,6 +13053,7 @@ _PUBLIC_ void 
ndr_print_spoolss_PrinterChangeFlags(struct ndr_print *ndr, const
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
"PRINTER_CHANGE_DELETE_PORT", PRINTER_CHANGE_DELETE_PORT, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
"PRINTER_CHANGE_ADD_PRINT_PROCESSOR", PRINTER_CHANGE_ADD_PRINT_PROCESSOR, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
"PRINTER_CHANGE_DELETE_PRINT_PROCESSOR", PRINTER_CHANGE_DELETE_PRINT_PROCESSOR, 
r);
+   ndr_print_bitmap_flag(ndr, sizeof(uint32_t), "PRINTER_CHANGE_SERVER", 
PRINTER_CHANGE_SERVER, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
"PRINTER_CHANGE_ADD_PRINTER_DRIVER", PRINTER_CHANGE_ADD_PRINTER_DRIVER, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
"PRINTER_CHANGE_SET_PRINTER_DRIVER", PRINTER_CHANGE_SET_PRINTER_DRIVER, r);
ndr_print_bitmap_flag(ndr, sizeof(uint32_t), 
"PRINTER_CHANGE_DELETE_PRINTER_DRIVER", PRINTER_CHANGE_DELETE_PRINTER_DRIVER, 
r);
@@ -13445,7 +13446,7 @@ static enum ndr_err_code 
ndr_push_spoolss_NotifyData(struct ndr_push *ndr, int n
break; }
 
case 3: {
-   NDR_CHECK(ndr_push_unique_ptr(ndr, r->devmode));
+   
NDR_CHECK(ndr_push_spoolss_DevmodeContainer(ndr, NDR_SCALARS, &r->devmode));
break; }
 
case 4: {
@@ -13471,9 +13472,7 @@ static enum ndr_err_code 
ndr_push_spoolss_NotifyData(struct ndr_push *ndr, int n
break;
 
case 3:
-   if (r->devmode) {
-   
NDR_CHECK(ndr_push_spoolss_DeviceMode(ndr, NDR_SCALARS, r->devmode));
-   }
+   
NDR_CHECK(ndr_push_spoolss_DevmodeContainer(ndr, NDR_BUFFERS, &r->devmode));
break;
 
case 4:
@@ -13495,7 +13494,6 @@ static enum ndr_err_code 
ndr_pull_spoolss_NotifyData(struct ndr_pull *ndr, int n
 {
int level;
uint32_t _level;
-   TALLOC_CTX *_mem_save_devmode_0;
level = ndr_pull_get_switch_value(ndr, r);
if (ndr_flags & NDR_SCALARS) {
NDR_CHECK(ndr_pull_uint32(ndr, NDR_SCALARS, &_level));
@@ -13515,13 +13513,7 @@ static enum ndr_err_code 
ndr_pull_spoolss_NotifyData(struct ndr_pull *ndr, int n
break; }
 
case 3: {
-   uint32_t _ptr_devmode;
-   NDR_CHECK(ndr_pull_generic_ptr(ndr, 
&_ptr_devmode));
-   if (_ptr_devmode) {
-   NDR_PULL_ALLOC(ndr, r->devmode);
-   } else {
-   r->devmode = NULL;
-   }
+   
NDR_CHECK(ndr_pull_spoolss_DevmodeContainer(ndr, NDR_SCALARS, &r->devmode));
break; }
 
case 4: {
@@ -13546,12 +13538,7 @

[SCM] Samba Shared Repository - branch v3-3-stable updated - release-3-3-0-133-ge6f556d

2009-02-23 Thread Karolin Seeger
The branch, v3-3-stable has been updated
   via  e6f556d3820a828bf4a59aceda0e3546e74ef61f (commit)
   via  4a7dadb2847cc40fbf1ece405526208e29f55ecc (commit)
  from  6d3dba353feab40605b25896d48864eb3c0ec096 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-stable


- Log -
commit e6f556d3820a828bf4a59aceda0e3546e74ef61f
Author: Karolin Seeger 
Date:   Mon Feb 23 09:46:52 2009 +0100

VERSION: Raise version number.

Karolin
(cherry picked from commit e5f5284cc036217d20d5ca690e14d87ba0ebccaa)

commit 4a7dadb2847cc40fbf1ece405526208e29f55ecc
Author: Karolin Seeger 
Date:   Mon Feb 23 09:44:08 2009 +0100

WHATSNEW: Updates changes since 3.3.0.

Karolin
(cherry picked from commit ded44fa523a5d964d0c31a1dac8cdc563d41fc15)

---

Summary of changes:
 WHATSNEW.txt   |   11 +++
 source/VERSION |2 +-
 2 files changed, 12 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/WHATSNEW.txt b/WHATSNEW.txt
index 74e8767..9377d89 100644
--- a/WHATSNEW.txt
+++ b/WHATSNEW.txt
@@ -35,6 +35,8 @@ o   Jeremy Allison 
 * BUG 6090: Fix renaming/deleting a "not matching/resolving" symlink.
 * BUG 6099: Try to fix domain join of Win7 Beta.
 * BUG 6117: Fix core dump of pdbedit -a.
+* BUG 6133: Fix deletion of non-ACL files on Solaris/ZFS/NFSv4 ACL
+  filesystem.
 * Fix Coverity IDs 115, 116, 117, 602.
 * Fix warning (bad handler prototype).
 * Unify the detection of the timespec code in configure.in, and the
@@ -135,12 +137,17 @@ o   Tim Prouty 
 
 o   Karolin Seeger 
 * Change "ldap ssl:ads" parameter to "ldap ssl ads".
+* Add manpages for vfs_acl_xattr and vfs_acl_tdb.
 
 
 o   Dan Sledz 
 * Fix double free caused by incorrect talloc_steal usage.
 
 
+o   Simo Sorce 
+* Build ldbrename.
+
+
 o   Aravind Srinivasan 
 * Make nmbd check all available interfaces for WINS before failing.
 
@@ -154,6 +161,10 @@ o   Yasuma Takeda 
 * BUG 6098: Fix ads_find_dc() in setups with "security = domain".
 
 
+o   Bo Yang 
+* Make libsmbclient work with DFS.
+
+
 ##
 Reporting bugs & Development Discussion
 ###
diff --git a/source/VERSION b/source/VERSION
index 16b5de4..d626975 100644
--- a/source/VERSION
+++ b/source/VERSION
@@ -25,7 +25,7 @@
 
 SAMBA_VERSION_MAJOR=3
 SAMBA_VERSION_MINOR=3
-SAMBA_VERSION_RELEASE=0
+SAMBA_VERSION_RELEASE=1
 
 
 # Bug fix releases use a letter for the patch revision #


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-3-test updated - release-3-2-0pre2-5004-ge5f5284

2009-02-23 Thread Karolin Seeger
The branch, v3-3-test has been updated
   via  e5f5284cc036217d20d5ca690e14d87ba0ebccaa (commit)
   via  ded44fa523a5d964d0c31a1dac8cdc563d41fc15 (commit)
  from  1ad5f50bdab761c7d3894e94f8fe3b171ec1b219 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-test


- Log -
commit e5f5284cc036217d20d5ca690e14d87ba0ebccaa
Author: Karolin Seeger 
Date:   Mon Feb 23 09:46:52 2009 +0100

VERSION: Raise version number.

Karolin

commit ded44fa523a5d964d0c31a1dac8cdc563d41fc15
Author: Karolin Seeger 
Date:   Mon Feb 23 09:44:08 2009 +0100

WHATSNEW: Updates changes since 3.3.0.

Karolin

---

Summary of changes:
 WHATSNEW.txt   |   11 +++
 source/VERSION |2 +-
 2 files changed, 12 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/WHATSNEW.txt b/WHATSNEW.txt
index 74e8767..9377d89 100644
--- a/WHATSNEW.txt
+++ b/WHATSNEW.txt
@@ -35,6 +35,8 @@ o   Jeremy Allison 
 * BUG 6090: Fix renaming/deleting a "not matching/resolving" symlink.
 * BUG 6099: Try to fix domain join of Win7 Beta.
 * BUG 6117: Fix core dump of pdbedit -a.
+* BUG 6133: Fix deletion of non-ACL files on Solaris/ZFS/NFSv4 ACL
+  filesystem.
 * Fix Coverity IDs 115, 116, 117, 602.
 * Fix warning (bad handler prototype).
 * Unify the detection of the timespec code in configure.in, and the
@@ -135,12 +137,17 @@ o   Tim Prouty 
 
 o   Karolin Seeger 
 * Change "ldap ssl:ads" parameter to "ldap ssl ads".
+* Add manpages for vfs_acl_xattr and vfs_acl_tdb.
 
 
 o   Dan Sledz 
 * Fix double free caused by incorrect talloc_steal usage.
 
 
+o   Simo Sorce 
+* Build ldbrename.
+
+
 o   Aravind Srinivasan 
 * Make nmbd check all available interfaces for WINS before failing.
 
@@ -154,6 +161,10 @@ o   Yasuma Takeda 
 * BUG 6098: Fix ads_find_dc() in setups with "security = domain".
 
 
+o   Bo Yang 
+* Make libsmbclient work with DFS.
+
+
 ##
 Reporting bugs & Development Discussion
 ###
diff --git a/source/VERSION b/source/VERSION
index 0056eb7..d248ea1 100644
--- a/source/VERSION
+++ b/source/VERSION
@@ -25,7 +25,7 @@
 
 SAMBA_VERSION_MAJOR=3
 SAMBA_VERSION_MINOR=3
-SAMBA_VERSION_RELEASE=0
+SAMBA_VERSION_RELEASE=1
 
 
 # Bug fix releases use a letter for the patch revision #


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-3-stable updated - release-3-3-0-131-g6d3dba3

2009-02-23 Thread Karolin Seeger
The branch, v3-3-stable has been updated
   via  6d3dba353feab40605b25896d48864eb3c0ec096 (commit)
   via  56bc6cbd7bb1f342b635eb139f4577dc990e4c1e (commit)
   via  45bcc61a38e3dbf75df6decaff9f1cac495420fc (commit)
   via  efda729240e998155e1ba226f14cb61ff80dcd9d (commit)
   via  81c7d422a1c99ad500539b3515a35223d9bf1181 (commit)
   via  922f61060c6a90bd197bfadabbf943e19318082b (commit)
   via  fb89a59aa5f7b5ca5b4f2c8f20b69641c3d5c486 (commit)
   via  2dbd2a237362c2dfe2fa8a0717dd672e65a98a4f (commit)
   via  57d6805bb18c0fdc05749b8322acce7b8f24dd58 (commit)
   via  49b4ec7040babe0b7fc23421874a5b1426c0b93f (commit)
  from  b93bb7a251cef874eb2d872718f845f00726a8bc (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-stable


- Log -
commit 6d3dba353feab40605b25896d48864eb3c0ec096
Author: Karolin Seeger 
Date:   Mon Feb 23 09:24:50 2009 +0100

s3/docs: Fix typo in man mount.cifs.

Thanks to Tobias Stoeckmann for reporting!

Karolin
(cherry picked from commit 09a7f93f6be66a8f2a124e49b4effe2b5863f01d)
(cherry picked from commit fdb5c65fc51784b6a159748ec4df3953b7d2c1cb)

commit 56bc6cbd7bb1f342b635eb139f4577dc990e4c1e
Author: Simo Sorce 
Date:   Sun Feb 22 01:06:28 2009 -0500

For some unknown reason ldbrename was not being built in samba3.
(cherry picked from commit b8fa66be1cbad021143653d4e79f04d79a01bd62)

commit 45bcc61a38e3dbf75df6decaff9f1cac495420fc
Author: Jeremy Allison 
Date:   Fri Feb 20 16:40:00 2009 -0800

Change smbc_set_credentials_with_fallback() (unreleased) to use
const approptiately.
Jeremy.
(cherry picked from commit 07c7085f25718915cda07e38a87a008a72abbf4f)

commit efda729240e998155e1ba226f14cb61ff80dcd9d
Author: Jeremy Allison 
Date:   Fri Feb 20 08:22:57 2009 -0800

Fix bug #6133 - Cannot delete non-ACL files on Solaris/ZFS/NFSv4 ACL 
filesystem.
As the NFSv4 ACL mapping code doesn't map write directory into the 
DELETE_CHILD
permission bit (which we require before allowing a delete) no one can delete
files without an explicit DELETE_CHILD bit set on the directory. Add this 
mapping.
Jeremy.
(cherry picked from commit 7df63394aff2a15d96112378a9e3b0acd9edc56a)

commit 81c7d422a1c99ad500539b3515a35223d9bf1181
Author: Derrell Lipman 
Date:   Fri Feb 20 10:03:55 2009 -0500

variable grouping: just my OCD desire to keep similar things together
(cherry picked from commit f84fd046fcff6c3310ef595fb3e4cbe774703d2a)

commit 922f61060c6a90bd197bfadabbf943e19318082b
Author: Bo Yang 
Date:   Fri Feb 20 12:21:52 2009 +0800

Make libsmbclient work with DFS

Signed-off-by: Derrell Lipman 
(cherry picked from commit 8457e7bba4ef2ba479340829bb89a3a8772f958b)

commit fb89a59aa5f7b5ca5b4f2c8f20b69641c3d5c486
Author: Karolin Seeger 
Date:   Fri Feb 20 14:14:54 2009 +0100

s3/docs: Add hint about getfattr in man vfs_acl_xattr.

Karolin
(cherry picked from commit 27307be0f726c899c0e8a0edfdf200650037bb61)
(cherry picked from commit 8c978a66168fd22c817e0710d7a70daf7d07b1ab)

commit 2dbd2a237362c2dfe2fa8a0717dd672e65a98a4f
Author: Karolin Seeger 
Date:   Fri Feb 20 13:32:44 2009 +0100

s3/docs: Add man vfs_acl_tdb.

Karolin
(cherry picked from commit 0fd1d4c0906158bab55871d53396bdc7ae533220)
(cherry picked from commit b6c900db66481f10d9acbc7fc6a3cbf6b537b486)

commit 57d6805bb18c0fdc05749b8322acce7b8f24dd58
Author: Karolin Seeger 
Date:   Fri Feb 20 13:32:22 2009 +0100

s3/docs: Add man vfs_acl_xattr.

Karolin
(cherry picked from commit 3b0114c0ba676dec2ece96983aff29257399f378)
(cherry picked from commit 7e3b9564af4ff2a9fa2de6a7ef2dd1ae16bc3d6a)

commit 49b4ec7040babe0b7fc23421874a5b1426c0b93f
Author: Karolin Seeger 
Date:   Fri Feb 20 09:20:16 2009 +0100

s3/docs: Fix several typos.

This fixes bug #6127.
Thanks to Justin T Pryzby 
for the review!

Karolin
(cherry picked from commit 54dbb030e2c6fed0abd0a3a89d08dad9b8a201a1)
(cherry picked from commit a4548e41c6f12e4703249c53ad3dc727d2839931)

---

Summary of changes:
 docs-xml/archives/THANKS   |2 +-
 .../man => docs-xml/manpages-3}/ldbrename.1.xml|0 
 docs-xml/manpages-3/mount.cifs.8.xml   |2 +-
 .../{vfs_xattr_tdb.8.xml => vfs_acl_tdb.8.xml} |   45 --
 .../{vfs_xattr_tdb.8.xml => vfs_acl_xattr.8.xml}   |   49 ++--
 docs-xml/smbdotconf/browse/enhancedbrowsing.xml|2 +-
 docs-xml/smbdotconf/locking/strictlocking.xml  |2 +-
 docs-xml/smbdotconf/misc/remoteannounce.xml|4 +-
 docs-xml/smbdotconf/misc/usershareallowguests.xml  |2 +-
 .../smbdotconf/misc/usershareprefixallowlist.xml   |4 +-
 .../smbdotconf/misc/usersharetemplateshare.xml |2 +-
 docs-xml/smbdotconf/

[SCM] Samba Shared Repository - branch v3-2-test updated - release-3-2-0pre2-3483-gbc53054

2009-02-23 Thread Stefan Metzmacher
The branch, v3-2-test has been updated
   via  bc53054616d442b1b28086181d81776f1c33834f (commit)
  from  b19f58ccd088a10e487a1261cadb4f3f41987391 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-2-test


- Log -
commit bc53054616d442b1b28086181d81776f1c33834f
Author: Björn Jacke 
Date:   Sun Feb 22 00:43:38 2009 +0100

all BSDs use this evironment variable

Signed-off-by: Stefan Metzmacher 
(cherry picked from commit cd6ae0de52164dd6f50b3614f2511acb3eb15993)
(cherry picked from commit 1ad5f50bdab761c7d3894e94f8fe3b171ec1b219)

---

Summary of changes:
 source/lib/replace/libreplace_ld.m4 |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source/lib/replace/libreplace_ld.m4 
b/source/lib/replace/libreplace_ld.m4
index 9995d69..cb54c25 100644
--- a/source/lib/replace/libreplace_ld.m4
+++ b/source/lib/replace/libreplace_ld.m4
@@ -292,7 +292,7 @@ AC_DEFUN([AC_LIBREPLACE_RUNTIME_LIB_PATH_VAR],
*linux*)
LIB_PATH_VAR=LD_LIBRARY_PATH
;;
-   *netbsd*)
+   *bsd*)
LIB_PATH_VAR=LD_LIBRARY_PATH
;;
*solaris*)


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-3-test updated - release-3-2-0pre2-5002-g1ad5f50

2009-02-23 Thread Stefan Metzmacher
The branch, v3-3-test has been updated
   via  1ad5f50bdab761c7d3894e94f8fe3b171ec1b219 (commit)
  from  fdb5c65fc51784b6a159748ec4df3953b7d2c1cb (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-test


- Log -
commit 1ad5f50bdab761c7d3894e94f8fe3b171ec1b219
Author: Björn Jacke 
Date:   Sun Feb 22 00:43:38 2009 +0100

all BSDs use this evironment variable

Signed-off-by: Stefan Metzmacher 
(cherry picked from commit cd6ae0de52164dd6f50b3614f2511acb3eb15993)

---

Summary of changes:
 source/lib/replace/libreplace_ld.m4 |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source/lib/replace/libreplace_ld.m4 
b/source/lib/replace/libreplace_ld.m4
index 81bde46..9529c5e 100644
--- a/source/lib/replace/libreplace_ld.m4
+++ b/source/lib/replace/libreplace_ld.m4
@@ -292,7 +292,7 @@ AC_DEFUN([AC_LIBREPLACE_RUNTIME_LIB_PATH_VAR],
*linux*)
LIB_PATH_VAR=LD_LIBRARY_PATH
;;
-   *netbsd*)
+   *bsd*)
LIB_PATH_VAR=LD_LIBRARY_PATH
;;
*solaris*)


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1074-gcd6ae0d

2009-02-23 Thread Stefan Metzmacher
The branch, master has been updated
   via  cd6ae0de52164dd6f50b3614f2511acb3eb15993 (commit)
  from  09a7f93f6be66a8f2a124e49b4effe2b5863f01d (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit cd6ae0de52164dd6f50b3614f2511acb3eb15993
Author: Björn Jacke 
Date:   Sun Feb 22 00:43:38 2009 +0100

all BSDs use this evironment variable

Signed-off-by: Stefan Metzmacher 

---

Summary of changes:
 lib/replace/libreplace_ld.m4 |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/lib/replace/libreplace_ld.m4 b/lib/replace/libreplace_ld.m4
index 81bde46..9529c5e 100644
--- a/lib/replace/libreplace_ld.m4
+++ b/lib/replace/libreplace_ld.m4
@@ -292,7 +292,7 @@ AC_DEFUN([AC_LIBREPLACE_RUNTIME_LIB_PATH_VAR],
*linux*)
LIB_PATH_VAR=LD_LIBRARY_PATH
;;
-   *netbsd*)
+   *bsd*)
LIB_PATH_VAR=LD_LIBRARY_PATH
;;
*solaris*)


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-0-test updated - release-3-0-32-153-geebc7e7

2009-02-23 Thread Karolin Seeger
The branch, v3-0-test has been updated
   via  eebc7e7ff0e6580b55ca0964a1f38096e11caa78 (commit)
  from  194fdee65f91e8ea88196d2cff1c678f868bb3df (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-0-test


- Log -
commit eebc7e7ff0e6580b55ca0964a1f38096e11caa78
Author: Karolin Seeger 
Date:   Mon Feb 23 09:24:50 2009 +0100

s3/docs: Fix typo in man mount.cifs.

Thanks to Tobias Stoeckmann for reporting!

Karolin
(cherry picked from commit 09a7f93f6be66a8f2a124e49b4effe2b5863f01d)
(cherry picked from commit fdb5c65fc51784b6a159748ec4df3953b7d2c1cb)
(cherry picked from commit b19f58ccd088a10e487a1261cadb4f3f41987391)

---

Summary of changes:
 docs-xml/manpages-3/mount.cifs.8.xml |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/docs-xml/manpages-3/mount.cifs.8.xml 
b/docs-xml/manpages-3/mount.cifs.8.xml
index 6c80089..86e4670 100644
--- a/docs-xml/manpages-3/mount.cifs.8.xml
+++ b/docs-xml/manpages-3/mount.cifs.8.xml
@@ -140,7 +140,7 @@ credentials file properly.
 same domain (e.g. running winbind or nss_ldap) and
 the server supports the Unix Extensions then the uid
 and gid can be retrieved from the server (and uid
-and gid would not have to be specifed on the mount. 
+and gid would not have to be specified on the mount.
 For servers which do not support the CIFS Unix
 extensions, the default uid (and gid) returned on lookup 
 of existing files will be the uid (gid) of the person


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-2-test updated - release-3-2-0pre2-3482-gb19f58c

2009-02-23 Thread Karolin Seeger
The branch, v3-2-test has been updated
   via  b19f58ccd088a10e487a1261cadb4f3f41987391 (commit)
  from  44e0e830c4c413054bdb30a62629993c4391c492 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-2-test


- Log -
commit b19f58ccd088a10e487a1261cadb4f3f41987391
Author: Karolin Seeger 
Date:   Mon Feb 23 09:24:50 2009 +0100

s3/docs: Fix typo in man mount.cifs.

Thanks to Tobias Stoeckmann for reporting!

Karolin
(cherry picked from commit 09a7f93f6be66a8f2a124e49b4effe2b5863f01d)
(cherry picked from commit fdb5c65fc51784b6a159748ec4df3953b7d2c1cb)

---

Summary of changes:
 docs-xml/manpages-3/mount.cifs.8.xml |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/docs-xml/manpages-3/mount.cifs.8.xml 
b/docs-xml/manpages-3/mount.cifs.8.xml
index c386592..ca8ae5f 100644
--- a/docs-xml/manpages-3/mount.cifs.8.xml
+++ b/docs-xml/manpages-3/mount.cifs.8.xml
@@ -140,7 +140,7 @@ credentials file properly.
 same domain (e.g. running winbind or nss_ldap) and
 the server supports the Unix Extensions then the uid
 and gid can be retrieved from the server (and uid
-and gid would not have to be specifed on the mount. 
+and gid would not have to be specified on the mount.
 For servers which do not support the CIFS Unix
 extensions, the default uid (and gid) returned on lookup 
 of existing files will be the uid (gid) of the person


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-3-test updated - release-3-2-0pre2-5001-gfdb5c65

2009-02-23 Thread Karolin Seeger
The branch, v3-3-test has been updated
   via  fdb5c65fc51784b6a159748ec4df3953b7d2c1cb (commit)
  from  b8fa66be1cbad021143653d4e79f04d79a01bd62 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-3-test


- Log -
commit fdb5c65fc51784b6a159748ec4df3953b7d2c1cb
Author: Karolin Seeger 
Date:   Mon Feb 23 09:24:50 2009 +0100

s3/docs: Fix typo in man mount.cifs.

Thanks to Tobias Stoeckmann for reporting!

Karolin
(cherry picked from commit 09a7f93f6be66a8f2a124e49b4effe2b5863f01d)

---

Summary of changes:
 docs-xml/manpages-3/mount.cifs.8.xml |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/docs-xml/manpages-3/mount.cifs.8.xml 
b/docs-xml/manpages-3/mount.cifs.8.xml
index 534f168..dae54e1 100644
--- a/docs-xml/manpages-3/mount.cifs.8.xml
+++ b/docs-xml/manpages-3/mount.cifs.8.xml
@@ -140,7 +140,7 @@ credentials file properly.
 same domain (e.g. running winbind or nss_ldap) and
 the server supports the Unix Extensions then the uid
 and gid can be retrieved from the server (and uid
-and gid would not have to be specifed on the mount. 
+and gid would not have to be specified on the mount.
 For servers which do not support the CIFS Unix
 extensions, the default uid (and gid) returned on lookup 
 of existing files will be the uid (gid) of the person


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1073-g09a7f93

2009-02-23 Thread Karolin Seeger
The branch, master has been updated
   via  09a7f93f6be66a8f2a124e49b4effe2b5863f01d (commit)
  from  ac0d452ac64cae90645ad49b1bb04f2e8bf89c9b (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 09a7f93f6be66a8f2a124e49b4effe2b5863f01d
Author: Karolin Seeger 
Date:   Mon Feb 23 09:24:50 2009 +0100

s3/docs: Fix typo in man mount.cifs.

Thanks to Tobias Stoeckmann for reporting!

Karolin

---

Summary of changes:
 docs-xml/manpages-3/mount.cifs.8.xml |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/docs-xml/manpages-3/mount.cifs.8.xml 
b/docs-xml/manpages-3/mount.cifs.8.xml
index c386592..ca8ae5f 100644
--- a/docs-xml/manpages-3/mount.cifs.8.xml
+++ b/docs-xml/manpages-3/mount.cifs.8.xml
@@ -140,7 +140,7 @@ credentials file properly.
 same domain (e.g. running winbind or nss_ldap) and
 the server supports the Unix Extensions then the uid
 and gid can be retrieved from the server (and uid
-and gid would not have to be specifed on the mount. 
+and gid would not have to be specified on the mount.
 For servers which do not support the CIFS Unix
 extensions, the default uid (and gid) returned on lookup 
 of existing files will be the uid (gid) of the person


diff --git a/source/modules/nfs4_acls.c b/source/modules/nfs4_acls.c
index ba03847..7756f8f 100644
--- a/source/modules/nfs4_acls.c
+++ b/source/modules/nfs4_acls.c
@@ -44,10 +44,10 @@ typedef struct _SMB_ACL4_INT_T
SMB_ACE4_INT_T  *last;
 } SMB_ACL4_INT_T;
 
-static SMB_ACL4_INT_T *get_validated_aclint(SMB4ACL_T *acl)
+static SMB_ACL4_INT_T *get_validated_aclint(SMB4ACL_T *theacl)
 {
-   SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)acl;
-   if (acl==NULL)
+   SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)theacl;
+   if (theacl==NULL)
{
DEBUG(2, ("acl is NULL\n"));
errno = EINVAL;
@@ -83,21 +83,21 @@ static SMB_ACE4_INT_T *get_validated_aceint(SMB4ACE_T *ace)
 SMB4ACL_T *smb_create_smb4acl(void)
 {
TALLOC_CTX *mem_ctx = talloc_tos();
-   SMB_ACL4_INT_T  *acl = (SMB_ACL4_INT_T *)TALLOC_ZERO_SIZE(mem_ctx, 
sizeof(SMB_ACL4_INT_T));
-   if (acl==NULL)
+   SMB_ACL4_INT_T  *theacl = (SMB_ACL4_INT_T *)TALLOC_ZERO_SIZE(mem_ctx, 
sizeof(SMB_ACL4_INT_T));
+   if (theacl==NULL)
{
DEBUG(0, ("TALLOC_SIZE failed\n"));
errno = ENOMEM;
return NULL;
}
-   acl->magic = SMB_ACL4_INT_MAGIC;
-   /* acl->first, last = NULL not needed */
-   return (SMB4ACL_T *)acl;
+   theacl->magic = SMB_ACL4_INT_MAGIC;
+   /* theacl->first, last = NULL not needed */
+   return (SMB4ACL_T *)theacl;
 }
 
-SMB4ACE_T *smb_add_ace4(SMB4ACL_T *acl, SMB_ACE4PROP_T *prop)
+SMB4ACE_T *smb_add_ace4(SMB4ACL_T *theacl, SMB_ACE4PROP_T *prop)
 {
-   SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+   SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
TALLOC_CTX *mem_ctx = talloc_tos();
SMB_ACE4_INT_T *ace;
 
@@ -143,18 +143,18 @@ SMB4ACE_T *smb_next_ace4(SMB4ACE_T *ace)
return (SMB4ACE_T *)aceint->next;
 }
 
-SMB4ACE_T *smb_first_ace4(SMB4ACL_T *acl)
+SMB4ACE_T *smb_first_ace4(SMB4ACL_T *theacl)
 {
-   SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+   SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
if (aclint==NULL)
return NULL;
 
return (SMB4ACE_T *)aclint->first;
 }
 
-uint32 smb_get_naces(SMB4ACL_T *acl)
+uint32 smb_get_naces(SMB4ACL_T *theacl)
 {
- 

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1099-g0b62cdb

2009-02-23 Thread Jeremy Allison
The branch, master has been updated
   via  0b62cdbed0867d0712821953700062727f668c65 (commit)
  from  1cd7fe71940b7420dd478321b8368a31ae713917 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 0b62cdbed0867d0712821953700062727f668c65
Author: Jeremy Allison 
Date:   Mon Feb 23 15:03:29 2009 -0800

Quieten down a boatload of shadowed variable warnings on Solaris.
Makes real problems easier to spot.
Jeremy.

---

Summary of changes:
 librpc/ndr/ndr_sec_helper.c   |8 ++--
 source3/modules/nfs4_acls.c   |   84 ++--
 source3/modules/nfs4_acls.h   |   10 ++--
 source3/registry/reg_dispatcher.c |8 ++--
 4 files changed, 55 insertions(+), 55 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/modules/nfs4_acls.c b/source3/modules/nfs4_acls.c
index ba03847..7756f8f 100644
--- a/source3/modules/nfs4_acls.c
+++ b/source3/modules/nfs4_acls.c
@@ -44,10 +44,10 @@ typedef struct _SMB_ACL4_INT_T
SMB_ACE4_INT_T  *last;
 } SMB_ACL4_INT_T;
 
-static SMB_ACL4_INT_T *get_validated_aclint(SMB4ACL_T *acl)
+static SMB_ACL4_INT_T *get_validated_aclint(SMB4ACL_T *theacl)
 {
-   SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)acl;
-   if (acl==NULL)
+   SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)theacl;
+   if (theacl==NULL)
{
DEBUG(2, ("acl is NULL\n"));
errno = EINVAL;
@@ -83,21 +83,21 @@ static SMB_ACE4_INT_T *get_validated_aceint(SMB4ACE_T *ace)
 SMB4ACL_T *smb_create_smb4acl(void)
 {
TALLOC_CTX *mem_ctx = talloc_tos();
-   SMB_ACL4_INT_T  *acl = (SMB_ACL4_INT_T *)TALLOC_ZERO_SIZE(mem_ctx, 
sizeof(SMB_ACL4_INT_T));
-   if (acl==NULL)
+   SMB_ACL4_INT_T  *theacl = (SMB_ACL4_INT_T *)TALLOC_ZERO_SIZE(mem_ctx, 
sizeof(SMB_ACL4_INT_T));
+   if (theacl==NULL)
{
DEBUG(0, ("TALLOC_SIZE failed\n"));
errno = ENOMEM;
return NULL;
}
-   acl->magic = SMB_ACL4_INT_MAGIC;
-   /* acl->first, last = NULL not needed */
-   return (SMB4ACL_T *)acl;
+   theacl->magic = SMB_ACL4_INT_MAGIC;
+   /* theacl->first, last = NULL not needed */
+   return (SMB4ACL_T *)theacl;
 }
 
-SMB4ACE_T *smb_add_ace4(SMB4ACL_T *acl, SMB_ACE4PROP_T *prop)
+SMB4ACE_T *smb_add_ace4(SMB4ACL_T *theacl, SMB_ACE4PROP_T *prop)
 {
-   SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+   SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
TALLOC_CTX *mem_ctx = talloc_tos();
SMB_ACE4_INT_T *ace;
 
@@ -143,18 +143,18 @@ SMB4ACE_T *smb_next_ace4(SMB4ACE_T *ace)
return (SMB4ACE_T *)aceint->next;
 }
 
-SMB4ACE_T *smb_first_ace4(SMB4ACL_T *acl)
+SMB4ACE_T *smb_first_ace4(SMB4ACL_T *theacl)
 {
-   SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+   SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
if (aclint==NULL)
return NULL;
 
return (SMB4ACE_T *)aclint->first;
 }
 
-uint32 smb_get_naces(SMB4ACL_T *acl)
+uint32 smb_get_naces(SMB4ACL_T *theacl)
 {
-   SMB_ACL4_INT_T *aclint = get_validated_aclint(acl);
+   SMB_ACL4_INT_T *aclint = get_validated_aclint(theacl);
if (aclint==NULL)
return 0;
 
@@ -195,7 +195,7 @@ static int smbacl4_fGetFileOwner(files_struct *fsp, 
SMB_STRUCT_STAT *psbuf)
return 0;
 }
 
-static bool smbacl4_nfs42win(TALLOC_CTX *mem_ctx, SMB4ACL_T *acl, /* in */
+static bool smbacl4_nfs42win(TALLOC_CTX *mem_ctx, SMB4ACL_T *theacl, /* in */
DOM_SID *psid_owner, /* in */
DOM_SID *psid_group, /* in */
bool is_directory, /* in */
@@ -203,15 +203,15 @@ static bool smbacl4_nfs42win(TALLOC_CTX *mem_ctx, 
SMB4ACL_T *acl, /* in */
int *pgood_aces /* out */
 )
 {
-   SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)acl;
+   SMB_ACL4_INT_T *aclint = (SMB_ACL4_INT_T *)theacl;
SMB_ACE4_INT_T *aceint;
SEC_ACE

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha6-1098-g1cd7fe7

2009-02-23 Thread Simo Sorce
The branch, master has been updated
   via  1cd7fe71940b7420dd478321b8368a31ae713917 (commit)
  from  cf7539abfb0f6e6956bed7a478e0cda6ab734674 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 1cd7fe71940b7420dd478321b8368a31ae713917
Author: Simo Sorce 
Date:   Mon Feb 23 17:35:49 2009 -0500

Fix headers, ldb_includes.h is a private header,
do not reference it from ldb.h

---

Summary of changes:
 source4/dsdb/samdb/ldb_modules/config.mk   |4 ++--
 source4/dsdb/samdb/ldb_modules/linked_attributes.c |1 +
 source4/dsdb/samdb/ldb_modules/objectclass.c   |1 +
 source4/dsdb/samdb/ldb_modules/ranged_results.c|1 +
 source4/dsdb/samdb/ldb_modules/samba3sam.c |2 +-
 source4/dsdb/samdb/ldb_modules/update_keytab.c |1 +
 source4/dsdb/schema/schema_set.c   |1 +
 source4/lib/ldb/Makefile.in|2 +-
 source4/lib/ldb/common/ldb_modules.c   |5 +
 source4/lib/ldb/include/ldb.h  |   14 +-
 source4/lib/ldb/include/ldb_includes.h |9 -
 source4/lib/ldb/include/ldb_private.h  |5 +
 source4/lib/ldb/ldb_ildap/ldb_ildap.c  |3 +--
 source4/lib/ldb/ldb_ldap/ldb_ldap.c|1 +
 source4/lib/ldb/ldb_map/ldb_map.c  |2 --
 source4/lib/ldb/ldb_map/ldb_map.h  |2 ++
 source4/lib/ldb/ldb_map/ldb_map_inbound.c  |2 --
 source4/lib/ldb/ldb_map/ldb_map_outbound.c |2 --
 source4/lib/ldb/ldb_map/ldb_map_private.h  |1 +
 source4/lib/ldb/ldb_tdb/ldb_index.c|1 +
 source4/lib/ldb/ldb_tdb/ldb_tdb.h  |8 +---
 source4/lib/ldb/modules/operational.c  |5 +
 source4/lib/ldb/modules/paged_results.c|1 +
 source4/lib/ldb/modules/rdn_name.c |1 +
 source4/lib/ldb/tools/cmdline.c|1 +
 source4/lib/ldb/tools/ldbedit.c|2 +-
 source4/lib/ldb/tools/ldbsearch.c  |1 +
 source4/lib/ldb/tools/ldbtest.c|1 +
 28 files changed, 42 insertions(+), 38 deletions(-)


Changeset truncated at 500 lines:

-- 
Samba Shared Repository